# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
from . import _utilities
import typing
# Export this package's modules as members:
from .access_group import *
from .access_group_project import *
from .alias import *
from .attack_challenge_mode import *
from .custom_certificate import *
from .custom_environment import *
from .deployment import *
from .dns_record import *
from .edge_config import *
from .edge_config_item import *
from .edge_config_schema import *
from .edge_config_token import *
from .firewall_bypass import *
from .firewall_config import *
from .get_access_group import *
from .get_access_group_project import *
from .get_alias import *
from .get_attack_challenge_mode import *
from .get_custom_environment import *
from .get_deployment import *
from .get_domain_config import *
from .get_dsync_groups import *
from .get_edge_config import *
from .get_edge_config_item import *
from .get_edge_config_schema import *
from .get_edge_config_token import *
from .get_endpoint_verification import *
from .get_file import *
from .get_log_drain import *
from .get_microfrontend_group import *
from .get_microfrontend_group_membership import *
from .get_network import *
from .get_prebuilt_project import *
from .get_project import *
from .get_project_deployment_retention import *
from .get_project_directory import *
from .get_project_members import *
from .get_project_rolling_release import *
from .get_shared_environment_variable import *
from .get_team_config import *
from .get_team_member import *
from .integration_project_access import *
from .log_drain import *
from .microfrontend_group import *
from .microfrontend_group_membership import *
from .network import *
from .project import *
from .project_crons import *
from .project_deployment_retention import *
from .project_domain import *
from .project_environment_variable import *
from .project_environment_variables import *
from .project_members import *
from .project_rolling_release import *
from .provider import *
from .shared_environment_variable import *
from .shared_environment_variable_project_link import *
from .team_config import *
from .team_member import *
from .webhook import *
from ._inputs import *
from . import outputs

# Make subpackages available:
if typing.TYPE_CHECKING:
    import pulumiverse_vercel.config as __config
    config = __config
else:
    config = _utilities.lazy_import('pulumiverse_vercel.config')

_utilities.register(
    resource_modules="""
[
 {
  "pkg": "vercel",
  "mod": "index/accessGroup",
  "fqn": "pulumiverse_vercel",
  "classes": {
   "vercel:index/accessGroup:AccessGroup": "AccessGroup"
  }
 },
 {
  "pkg": "vercel",
  "mod": "index/accessGroupProject",
  "fqn": "pulumiverse_vercel",
  "classes": {
   "vercel:index/accessGroupProject:AccessGroupProject": "AccessGroupProject"
  }
 },
 {
  "pkg": "vercel",
  "mod": "index/alias",
  "fqn": "pulumiverse_vercel",
  "classes": {
   "vercel:index/alias:Alias": "Alias"
  }
 },
 {
  "pkg": "vercel",
  "mod": "index/attackChallengeMode",
  "fqn": "pulumiverse_vercel",
  "classes": {
   "vercel:index/attackChallengeMode:AttackChallengeMode": "AttackChallengeMode"
  }
 },
 {
  "pkg": "vercel",
  "mod": "index/customCertificate",
  "fqn": "pulumiverse_vercel",
  "classes": {
   "vercel:index/customCertificate:CustomCertificate": "CustomCertificate"
  }
 },
 {
  "pkg": "vercel",
  "mod": "index/customEnvironment",
  "fqn": "pulumiverse_vercel",
  "classes": {
   "vercel:index/customEnvironment:CustomEnvironment": "CustomEnvironment"
  }
 },
 {
  "pkg": "vercel",
  "mod": "index/deployment",
  "fqn": "pulumiverse_vercel",
  "classes": {
   "vercel:index/deployment:Deployment": "Deployment"
  }
 },
 {
  "pkg": "vercel",
  "mod": "index/dnsRecord",
  "fqn": "pulumiverse_vercel",
  "classes": {
   "vercel:index/dnsRecord:DnsRecord": "DnsRecord"
  }
 },
 {
  "pkg": "vercel",
  "mod": "index/edgeConfig",
  "fqn": "pulumiverse_vercel",
  "classes": {
   "vercel:index/edgeConfig:EdgeConfig": "EdgeConfig"
  }
 },
 {
  "pkg": "vercel",
  "mod": "index/edgeConfigItem",
  "fqn": "pulumiverse_vercel",
  "classes": {
   "vercel:index/edgeConfigItem:EdgeConfigItem": "EdgeConfigItem"
  }
 },
 {
  "pkg": "vercel",
  "mod": "index/edgeConfigSchema",
  "fqn": "pulumiverse_vercel",
  "classes": {
   "vercel:index/edgeConfigSchema:EdgeConfigSchema": "EdgeConfigSchema"
  }
 },
 {
  "pkg": "vercel",
  "mod": "index/edgeConfigToken",
  "fqn": "pulumiverse_vercel",
  "classes": {
   "vercel:index/edgeConfigToken:EdgeConfigToken": "EdgeConfigToken"
  }
 },
 {
  "pkg": "vercel",
  "mod": "index/firewallBypass",
  "fqn": "pulumiverse_vercel",
  "classes": {
   "vercel:index/firewallBypass:FirewallBypass": "FirewallBypass"
  }
 },
 {
  "pkg": "vercel",
  "mod": "index/firewallConfig",
  "fqn": "pulumiverse_vercel",
  "classes": {
   "vercel:index/firewallConfig:FirewallConfig": "FirewallConfig"
  }
 },
 {
  "pkg": "vercel",
  "mod": "index/integrationProjectAccess",
  "fqn": "pulumiverse_vercel",
  "classes": {
   "vercel:index/integrationProjectAccess:IntegrationProjectAccess": "IntegrationProjectAccess"
  }
 },
 {
  "pkg": "vercel",
  "mod": "index/logDrain",
  "fqn": "pulumiverse_vercel",
  "classes": {
   "vercel:index/logDrain:LogDrain": "LogDrain"
  }
 },
 {
  "pkg": "vercel",
  "mod": "index/microfrontendGroup",
  "fqn": "pulumiverse_vercel",
  "classes": {
   "vercel:index/microfrontendGroup:MicrofrontendGroup": "MicrofrontendGroup"
  }
 },
 {
  "pkg": "vercel",
  "mod": "index/microfrontendGroupMembership",
  "fqn": "pulumiverse_vercel",
  "classes": {
   "vercel:index/microfrontendGroupMembership:MicrofrontendGroupMembership": "MicrofrontendGroupMembership"
  }
 },
 {
  "pkg": "vercel",
  "mod": "index/network",
  "fqn": "pulumiverse_vercel",
  "classes": {
   "vercel:index/network:Network": "Network"
  }
 },
 {
  "pkg": "vercel",
  "mod": "index/project",
  "fqn": "pulumiverse_vercel",
  "classes": {
   "vercel:index/project:Project": "Project"
  }
 },
 {
  "pkg": "vercel",
  "mod": "index/projectCrons",
  "fqn": "pulumiverse_vercel",
  "classes": {
   "vercel:index/projectCrons:ProjectCrons": "ProjectCrons"
  }
 },
 {
  "pkg": "vercel",
  "mod": "index/projectDeploymentRetention",
  "fqn": "pulumiverse_vercel",
  "classes": {
   "vercel:index/projectDeploymentRetention:ProjectDeploymentRetention": "ProjectDeploymentRetention"
  }
 },
 {
  "pkg": "vercel",
  "mod": "index/projectDomain",
  "fqn": "pulumiverse_vercel",
  "classes": {
   "vercel:index/projectDomain:ProjectDomain": "ProjectDomain"
  }
 },
 {
  "pkg": "vercel",
  "mod": "index/projectEnvironmentVariable",
  "fqn": "pulumiverse_vercel",
  "classes": {
   "vercel:index/projectEnvironmentVariable:ProjectEnvironmentVariable": "ProjectEnvironmentVariable"
  }
 },
 {
  "pkg": "vercel",
  "mod": "index/projectEnvironmentVariables",
  "fqn": "pulumiverse_vercel",
  "classes": {
   "vercel:index/projectEnvironmentVariables:ProjectEnvironmentVariables": "ProjectEnvironmentVariables"
  }
 },
 {
  "pkg": "vercel",
  "mod": "index/projectMembers",
  "fqn": "pulumiverse_vercel",
  "classes": {
   "vercel:index/projectMembers:ProjectMembers": "ProjectMembers"
  }
 },
 {
  "pkg": "vercel",
  "mod": "index/projectRollingRelease",
  "fqn": "pulumiverse_vercel",
  "classes": {
   "vercel:index/projectRollingRelease:ProjectRollingRelease": "ProjectRollingRelease"
  }
 },
 {
  "pkg": "vercel",
  "mod": "index/sharedEnvironmentVariable",
  "fqn": "pulumiverse_vercel",
  "classes": {
   "vercel:index/sharedEnvironmentVariable:SharedEnvironmentVariable": "SharedEnvironmentVariable"
  }
 },
 {
  "pkg": "vercel",
  "mod": "index/sharedEnvironmentVariableProjectLink",
  "fqn": "pulumiverse_vercel",
  "classes": {
   "vercel:index/sharedEnvironmentVariableProjectLink:SharedEnvironmentVariableProjectLink": "SharedEnvironmentVariableProjectLink"
  }
 },
 {
  "pkg": "vercel",
  "mod": "index/teamConfig",
  "fqn": "pulumiverse_vercel",
  "classes": {
   "vercel:index/teamConfig:TeamConfig": "TeamConfig"
  }
 },
 {
  "pkg": "vercel",
  "mod": "index/teamMember",
  "fqn": "pulumiverse_vercel",
  "classes": {
   "vercel:index/teamMember:TeamMember": "TeamMember"
  }
 },
 {
  "pkg": "vercel",
  "mod": "index/webhook",
  "fqn": "pulumiverse_vercel",
  "classes": {
   "vercel:index/webhook:Webhook": "Webhook"
  }
 }
]
""",
    resource_packages="""
[
 {
  "pkg": "vercel",
  "token": "pulumi:providers:vercel",
  "fqn": "pulumiverse_vercel",
  "class": "Provider"
 }
]
"""
)



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetEdgeConfigTokenResult',
    'AwaitableGetEdgeConfigTokenResult',
    'get_edge_config_token',
    'get_edge_config_token_output',
]

@pulumi.output_type
class GetEdgeConfigTokenResult:
    """
    A collection of values returned by getEdgeConfigToken.
    """
    def __init__(__self__, connection_string=None, edge_config_id=None, id=None, label=None, team_id=None, token=None):
        if connection_string and not isinstance(connection_string, str):
            raise TypeError("Expected argument 'connection_string' to be a str")
        pulumi.set(__self__, "connection_string", connection_string)
        if edge_config_id and not isinstance(edge_config_id, str):
            raise TypeError("Expected argument 'edge_config_id' to be a str")
        pulumi.set(__self__, "edge_config_id", edge_config_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if label and not isinstance(label, str):
            raise TypeError("Expected argument 'label' to be a str")
        pulumi.set(__self__, "label", label)
        if team_id and not isinstance(team_id, str):
            raise TypeError("Expected argument 'team_id' to be a str")
        pulumi.set(__self__, "team_id", team_id)
        if token and not isinstance(token, str):
            raise TypeError("Expected argument 'token' to be a str")
        pulumi.set(__self__, "token", token)

    @_builtins.property
    @pulumi.getter(name="connectionString")
    def connection_string(self) -> _builtins.str:
        """
        A connection string is a URL that connects a project to an Edge Config. The variable can be called anything, but our Edge Config client SDK will search for process.env.EDGE_CONFIG by default.
        """
        return pulumi.get(self, "connection_string")

    @_builtins.property
    @pulumi.getter(name="edgeConfigId")
    def edge_config_id(self) -> _builtins.str:
        """
        The label of the Edge Config Token.
        """
        return pulumi.get(self, "edge_config_id")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The ID of this resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def label(self) -> _builtins.str:
        """
        The label of the Edge Config Token.
        """
        return pulumi.get(self, "label")

    @_builtins.property
    @pulumi.getter(name="teamId")
    def team_id(self) -> _builtins.str:
        """
        The ID of the team the Edge Config should exist under. Required when configuring a team resource if a default team has not been set in the provider.
        """
        return pulumi.get(self, "team_id")

    @_builtins.property
    @pulumi.getter
    def token(self) -> _builtins.str:
        """
        A read access token used for authenticating against the Edge Config's endpoint for high volume, low-latency requests.
        """
        return pulumi.get(self, "token")


class AwaitableGetEdgeConfigTokenResult(GetEdgeConfigTokenResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetEdgeConfigTokenResult(
            connection_string=self.connection_string,
            edge_config_id=self.edge_config_id,
            id=self.id,
            label=self.label,
            team_id=self.team_id,
            token=self.token)


def get_edge_config_token(edge_config_id: Optional[_builtins.str] = None,
                          team_id: Optional[_builtins.str] = None,
                          token: Optional[_builtins.str] = None,
                          opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetEdgeConfigTokenResult:
    """
    Provides information about an existing Edge Config Token.

    An Edge Config is a global data store that enables experimentation with feature flags, A/B testing, critical redirects, and more.

    An Edge Config token is used to authenticate against an Edge Config's endpoint.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_vercel as vercel

    test = vercel.get_edge_config_token(edge_config_id="ecfg_xxxxxxxxxxxxxxxxxxxxxxxxxxxx",
        token="xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx")
    ```


    :param _builtins.str edge_config_id: The label of the Edge Config Token.
    :param _builtins.str team_id: The ID of the team the Edge Config should exist under. Required when configuring a team resource if a default team has not been set in the provider.
    :param _builtins.str token: A read access token used for authenticating against the Edge Config's endpoint for high volume, low-latency requests.
    """
    __args__ = dict()
    __args__['edgeConfigId'] = edge_config_id
    __args__['teamId'] = team_id
    __args__['token'] = token
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('vercel:index/getEdgeConfigToken:getEdgeConfigToken', __args__, opts=opts, typ=GetEdgeConfigTokenResult).value

    return AwaitableGetEdgeConfigTokenResult(
        connection_string=pulumi.get(__ret__, 'connection_string'),
        edge_config_id=pulumi.get(__ret__, 'edge_config_id'),
        id=pulumi.get(__ret__, 'id'),
        label=pulumi.get(__ret__, 'label'),
        team_id=pulumi.get(__ret__, 'team_id'),
        token=pulumi.get(__ret__, 'token'))
def get_edge_config_token_output(edge_config_id: Optional[pulumi.Input[_builtins.str]] = None,
                                 team_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                 token: Optional[pulumi.Input[_builtins.str]] = None,
                                 opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetEdgeConfigTokenResult]:
    """
    Provides information about an existing Edge Config Token.

    An Edge Config is a global data store that enables experimentation with feature flags, A/B testing, critical redirects, and more.

    An Edge Config token is used to authenticate against an Edge Config's endpoint.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_vercel as vercel

    test = vercel.get_edge_config_token(edge_config_id="ecfg_xxxxxxxxxxxxxxxxxxxxxxxxxxxx",
        token="xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx")
    ```


    :param _builtins.str edge_config_id: The label of the Edge Config Token.
    :param _builtins.str team_id: The ID of the team the Edge Config should exist under. Required when configuring a team resource if a default team has not been set in the provider.
    :param _builtins.str token: A read access token used for authenticating against the Edge Config's endpoint for high volume, low-latency requests.
    """
    __args__ = dict()
    __args__['edgeConfigId'] = edge_config_id
    __args__['teamId'] = team_id
    __args__['token'] = token
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('vercel:index/getEdgeConfigToken:getEdgeConfigToken', __args__, opts=opts, typ=GetEdgeConfigTokenResult)
    return __ret__.apply(lambda __response__: GetEdgeConfigTokenResult(
        connection_string=pulumi.get(__response__, 'connection_string'),
        edge_config_id=pulumi.get(__response__, 'edge_config_id'),
        id=pulumi.get(__response__, 'id'),
        label=pulumi.get(__response__, 'label'),
        team_id=pulumi.get(__response__, 'team_id'),
        token=pulumi.get(__response__, 'token')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetAliasResult',
    'AwaitableGetAliasResult',
    'get_alias',
    'get_alias_output',
]

@pulumi.output_type
class GetAliasResult:
    """
    A collection of values returned by getAlias.
    """
    def __init__(__self__, alias=None, deployment_id=None, id=None, team_id=None):
        if alias and not isinstance(alias, str):
            raise TypeError("Expected argument 'alias' to be a str")
        pulumi.set(__self__, "alias", alias)
        if deployment_id and not isinstance(deployment_id, str):
            raise TypeError("Expected argument 'deployment_id' to be a str")
        pulumi.set(__self__, "deployment_id", deployment_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if team_id and not isinstance(team_id, str):
            raise TypeError("Expected argument 'team_id' to be a str")
        pulumi.set(__self__, "team_id", team_id)

    @_builtins.property
    @pulumi.getter
    def alias(self) -> _builtins.str:
        """
        The Alias or Alias ID to be retrieved.
        """
        return pulumi.get(self, "alias")

    @_builtins.property
    @pulumi.getter(name="deploymentId")
    def deployment_id(self) -> _builtins.str:
        """
        The ID of the Deployment the Alias is associated with.
        """
        return pulumi.get(self, "deployment_id")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The ID of this resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="teamId")
    def team_id(self) -> _builtins.str:
        """
        The ID of the team the Alias and Deployment exist under. Required when configuring a team resource if a default team has not been set in the provider.
        """
        return pulumi.get(self, "team_id")


class AwaitableGetAliasResult(GetAliasResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetAliasResult(
            alias=self.alias,
            deployment_id=self.deployment_id,
            id=self.id,
            team_id=self.team_id)


def get_alias(alias: Optional[_builtins.str] = None,
              team_id: Optional[_builtins.str] = None,
              opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetAliasResult:
    """
    Provides information about an existing Alias resource.

    An Alias allows a `Deployment` to be accessed through a different URL.


    :param _builtins.str alias: The Alias or Alias ID to be retrieved.
    :param _builtins.str team_id: The ID of the team the Alias and Deployment exist under. Required when configuring a team resource if a default team has not been set in the provider.
    """
    __args__ = dict()
    __args__['alias'] = alias
    __args__['teamId'] = team_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('vercel:index/getAlias:getAlias', __args__, opts=opts, typ=GetAliasResult).value

    return AwaitableGetAliasResult(
        alias=pulumi.get(__ret__, 'alias'),
        deployment_id=pulumi.get(__ret__, 'deployment_id'),
        id=pulumi.get(__ret__, 'id'),
        team_id=pulumi.get(__ret__, 'team_id'))
def get_alias_output(alias: Optional[pulumi.Input[_builtins.str]] = None,
                     team_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                     opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetAliasResult]:
    """
    Provides information about an existing Alias resource.

    An Alias allows a `Deployment` to be accessed through a different URL.


    :param _builtins.str alias: The Alias or Alias ID to be retrieved.
    :param _builtins.str team_id: The ID of the team the Alias and Deployment exist under. Required when configuring a team resource if a default team has not been set in the provider.
    """
    __args__ = dict()
    __args__['alias'] = alias
    __args__['teamId'] = team_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('vercel:index/getAlias:getAlias', __args__, opts=opts, typ=GetAliasResult)
    return __ret__.apply(lambda __response__: GetAliasResult(
        alias=pulumi.get(__response__, 'alias'),
        deployment_id=pulumi.get(__response__, 'deployment_id'),
        id=pulumi.get(__response__, 'id'),
        team_id=pulumi.get(__response__, 'team_id')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetEdgeConfigItemResult',
    'AwaitableGetEdgeConfigItemResult',
    'get_edge_config_item',
    'get_edge_config_item_output',
]

@pulumi.output_type
class GetEdgeConfigItemResult:
    """
    A collection of values returned by getEdgeConfigItem.
    """
    def __init__(__self__, id=None, key=None, team_id=None, value=None, value_json=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if key and not isinstance(key, str):
            raise TypeError("Expected argument 'key' to be a str")
        pulumi.set(__self__, "key", key)
        if team_id and not isinstance(team_id, str):
            raise TypeError("Expected argument 'team_id' to be a str")
        pulumi.set(__self__, "team_id", team_id)
        if value and not isinstance(value, str):
            raise TypeError("Expected argument 'value' to be a str")
        pulumi.set(__self__, "value", value)
        if value_json and not isinstance(value_json, dict):
            raise TypeError("Expected argument 'value_json' to be a dict")
        pulumi.set(__self__, "value_json", value_json)

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The ID of the Edge Config that the item should exist under.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def key(self) -> _builtins.str:
        """
        The name of the key you want to retrieve within your Edge Config.
        """
        return pulumi.get(self, "key")

    @_builtins.property
    @pulumi.getter(name="teamId")
    def team_id(self) -> _builtins.str:
        """
        The ID of the team the Edge Config should exist under. Required when configuring a team resource if a default team has not been set in the provider.
        """
        return pulumi.get(self, "team_id")

    @_builtins.property
    @pulumi.getter
    def value(self) -> _builtins.str:
        """
        The value assigned to the key (only set for string values).
        """
        return pulumi.get(self, "value")

    @_builtins.property
    @pulumi.getter(name="valueJson")
    def value_json(self) -> Any:
        """
        Structured JSON value (object/array/number/bool/null) assigned to the key.
        """
        return pulumi.get(self, "value_json")


class AwaitableGetEdgeConfigItemResult(GetEdgeConfigItemResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetEdgeConfigItemResult(
            id=self.id,
            key=self.key,
            team_id=self.team_id,
            value=self.value,
            value_json=self.value_json)


def get_edge_config_item(id: Optional[_builtins.str] = None,
                         key: Optional[_builtins.str] = None,
                         team_id: Optional[_builtins.str] = None,
                         opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetEdgeConfigItemResult:
    """
    Provides the value of an existing Edge Config Item.

    An Edge Config is a global data store that enables experimentation with feature flags, A/B testing, critical redirects, and more.

    An Edge Config Item is a value within an Edge Config.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_vercel as vercel

    example = vercel.get_edge_config(id="ecfg_xxxxxxxxxxxxxxxxxxxxxxxxxxxx")
    # Read a string item
    string_item = vercel.get_edge_config_item(id=example.id,
        key="foobar")
    # Read a JSON item
    json_item = vercel.get_edge_config_item(id=example.id,
        key="flags")
    ```


    :param _builtins.str id: The ID of the Edge Config that the item should exist under.
    :param _builtins.str key: The name of the key you want to retrieve within your Edge Config.
    :param _builtins.str team_id: The ID of the team the Edge Config should exist under. Required when configuring a team resource if a default team has not been set in the provider.
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['key'] = key
    __args__['teamId'] = team_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('vercel:index/getEdgeConfigItem:getEdgeConfigItem', __args__, opts=opts, typ=GetEdgeConfigItemResult).value

    return AwaitableGetEdgeConfigItemResult(
        id=pulumi.get(__ret__, 'id'),
        key=pulumi.get(__ret__, 'key'),
        team_id=pulumi.get(__ret__, 'team_id'),
        value=pulumi.get(__ret__, 'value'),
        value_json=pulumi.get(__ret__, 'value_json'))
def get_edge_config_item_output(id: Optional[pulumi.Input[_builtins.str]] = None,
                                key: Optional[pulumi.Input[_builtins.str]] = None,
                                team_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetEdgeConfigItemResult]:
    """
    Provides the value of an existing Edge Config Item.

    An Edge Config is a global data store that enables experimentation with feature flags, A/B testing, critical redirects, and more.

    An Edge Config Item is a value within an Edge Config.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_vercel as vercel

    example = vercel.get_edge_config(id="ecfg_xxxxxxxxxxxxxxxxxxxxxxxxxxxx")
    # Read a string item
    string_item = vercel.get_edge_config_item(id=example.id,
        key="foobar")
    # Read a JSON item
    json_item = vercel.get_edge_config_item(id=example.id,
        key="flags")
    ```


    :param _builtins.str id: The ID of the Edge Config that the item should exist under.
    :param _builtins.str key: The name of the key you want to retrieve within your Edge Config.
    :param _builtins.str team_id: The ID of the team the Edge Config should exist under. Required when configuring a team resource if a default team has not been set in the provider.
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['key'] = key
    __args__['teamId'] = team_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('vercel:index/getEdgeConfigItem:getEdgeConfigItem', __args__, opts=opts, typ=GetEdgeConfigItemResult)
    return __ret__.apply(lambda __response__: GetEdgeConfigItemResult(
        id=pulumi.get(__response__, 'id'),
        key=pulumi.get(__response__, 'key'),
        team_id=pulumi.get(__response__, 'team_id'),
        value=pulumi.get(__response__, 'value'),
        value_json=pulumi.get(__response__, 'value_json')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetMicrofrontendGroupResult',
    'AwaitableGetMicrofrontendGroupResult',
    'get_microfrontend_group',
    'get_microfrontend_group_output',
]

@pulumi.output_type
class GetMicrofrontendGroupResult:
    """
    A collection of values returned by getMicrofrontendGroup.
    """
    def __init__(__self__, default_app=None, id=None, name=None, slug=None, team_id=None):
        if default_app and not isinstance(default_app, dict):
            raise TypeError("Expected argument 'default_app' to be a dict")
        pulumi.set(__self__, "default_app", default_app)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if slug and not isinstance(slug, str):
            raise TypeError("Expected argument 'slug' to be a str")
        pulumi.set(__self__, "slug", slug)
        if team_id and not isinstance(team_id, str):
            raise TypeError("Expected argument 'team_id' to be a str")
        pulumi.set(__self__, "team_id", team_id)

    @_builtins.property
    @pulumi.getter(name="defaultApp")
    def default_app(self) -> 'outputs.GetMicrofrontendGroupDefaultAppResult':
        """
        The default app for the project. Used as the entry point for the microfrontend.
        """
        return pulumi.get(self, "default_app")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        A unique identifier for the group of microfrontends. Example: mfe_12HKQaOmR5t5Uy6vdcQsNIiZgHGB
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        A human readable name for the microfrontends group.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def slug(self) -> _builtins.str:
        """
        A slugified version of the name.
        """
        return pulumi.get(self, "slug")

    @_builtins.property
    @pulumi.getter(name="teamId")
    def team_id(self) -> _builtins.str:
        """
        The team ID to add the project to. Required when configuring a team resource if a default team has not been set in the provider.
        """
        return pulumi.get(self, "team_id")


class AwaitableGetMicrofrontendGroupResult(GetMicrofrontendGroupResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetMicrofrontendGroupResult(
            default_app=self.default_app,
            id=self.id,
            name=self.name,
            slug=self.slug,
            team_id=self.team_id)


def get_microfrontend_group(id: Optional[_builtins.str] = None,
                            team_id: Optional[_builtins.str] = None,
                            opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetMicrofrontendGroupResult:
    """
    Provides information about an existing Microfrontend Group.

    A Microfrontend Group is a definition of a microfrontend belonging to a Vercel Team.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_vercel as vercel

    example = vercel.get_microfrontend_group(id="mfe_xxxxxxxxxxxxxxxxxxxxxxxxxxxx")
    ```


    :param _builtins.str id: A unique identifier for the group of microfrontends. Example: mfe_12HKQaOmR5t5Uy6vdcQsNIiZgHGB
    :param _builtins.str team_id: The team ID to add the project to. Required when configuring a team resource if a default team has not been set in the provider.
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['teamId'] = team_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('vercel:index/getMicrofrontendGroup:getMicrofrontendGroup', __args__, opts=opts, typ=GetMicrofrontendGroupResult).value

    return AwaitableGetMicrofrontendGroupResult(
        default_app=pulumi.get(__ret__, 'default_app'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        slug=pulumi.get(__ret__, 'slug'),
        team_id=pulumi.get(__ret__, 'team_id'))
def get_microfrontend_group_output(id: Optional[pulumi.Input[_builtins.str]] = None,
                                   team_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                   opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetMicrofrontendGroupResult]:
    """
    Provides information about an existing Microfrontend Group.

    A Microfrontend Group is a definition of a microfrontend belonging to a Vercel Team.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_vercel as vercel

    example = vercel.get_microfrontend_group(id="mfe_xxxxxxxxxxxxxxxxxxxxxxxxxxxx")
    ```


    :param _builtins.str id: A unique identifier for the group of microfrontends. Example: mfe_12HKQaOmR5t5Uy6vdcQsNIiZgHGB
    :param _builtins.str team_id: The team ID to add the project to. Required when configuring a team resource if a default team has not been set in the provider.
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['teamId'] = team_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('vercel:index/getMicrofrontendGroup:getMicrofrontendGroup', __args__, opts=opts, typ=GetMicrofrontendGroupResult)
    return __ret__.apply(lambda __response__: GetMicrofrontendGroupResult(
        default_app=pulumi.get(__response__, 'default_app'),
        id=pulumi.get(__response__, 'id'),
        name=pulumi.get(__response__, 'name'),
        slug=pulumi.get(__response__, 'slug'),
        team_id=pulumi.get(__response__, 'team_id')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['ProjectEnvironmentVariableArgs', 'ProjectEnvironmentVariable']

@pulumi.input_type
class ProjectEnvironmentVariableArgs:
    def __init__(__self__, *,
                 key: pulumi.Input[_builtins.str],
                 project_id: pulumi.Input[_builtins.str],
                 comment: Optional[pulumi.Input[_builtins.str]] = None,
                 custom_environment_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 git_branch: Optional[pulumi.Input[_builtins.str]] = None,
                 sensitive: Optional[pulumi.Input[_builtins.bool]] = None,
                 targets: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 team_id: Optional[pulumi.Input[_builtins.str]] = None,
                 value: Optional[pulumi.Input[_builtins.str]] = None,
                 value_wo: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a ProjectEnvironmentVariable resource.
        :param pulumi.Input[_builtins.str] key: The name of the Environment Variable.
        :param pulumi.Input[_builtins.str] project_id: The ID of the Vercel project.
        :param pulumi.Input[_builtins.str] comment: A comment explaining what the environment variable is for.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] custom_environment_ids: The IDs of Custom Environments that the Environment Variable should be present on. At least one of `target` or `custom_environment_ids` must be set.
        :param pulumi.Input[_builtins.str] git_branch: The git branch of the Environment Variable.
        :param pulumi.Input[_builtins.bool] sensitive: Whether the Environment Variable is sensitive or not. (May be affected by a [team-wide environment variable policy](https://vercel.com/docs/projects/environment-variables/sensitive-environment-variables#environment-variables-policy))
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] targets: The environments that the Environment Variable should be present on. Valid targets are either `production`, `preview`, or `development`. At least one of `target` or `custom_environment_ids` must be set.
        :param pulumi.Input[_builtins.str] team_id: The ID of the Vercel team.Required when configuring a team resource if a default team has not been set in the provider.
        :param pulumi.Input[_builtins.str] value: (Optional, exactly one of `value` or `value_wo` is required) The value of the Environment Variable.
        :param pulumi.Input[_builtins.str] value_wo: **NOTE:** This field is write-only and its value will not be updated in state as part of read operations.
               (Optional, Write-Only, exactly one of `value` or `value_wo` is required) The value of the Environment Variable, from an `ephemeral` resource.
        """
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "project_id", project_id)
        if comment is not None:
            pulumi.set(__self__, "comment", comment)
        if custom_environment_ids is not None:
            pulumi.set(__self__, "custom_environment_ids", custom_environment_ids)
        if git_branch is not None:
            pulumi.set(__self__, "git_branch", git_branch)
        if sensitive is not None:
            pulumi.set(__self__, "sensitive", sensitive)
        if targets is not None:
            pulumi.set(__self__, "targets", targets)
        if team_id is not None:
            pulumi.set(__self__, "team_id", team_id)
        if value is not None:
            pulumi.set(__self__, "value", value)
        if value_wo is not None:
            pulumi.set(__self__, "value_wo", value_wo)

    @_builtins.property
    @pulumi.getter
    def key(self) -> pulumi.Input[_builtins.str]:
        """
        The name of the Environment Variable.
        """
        return pulumi.get(self, "key")

    @key.setter
    def key(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "key", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Input[_builtins.str]:
        """
        The ID of the Vercel project.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def comment(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        A comment explaining what the environment variable is for.
        """
        return pulumi.get(self, "comment")

    @comment.setter
    def comment(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "comment", value)

    @_builtins.property
    @pulumi.getter(name="customEnvironmentIds")
    def custom_environment_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        The IDs of Custom Environments that the Environment Variable should be present on. At least one of `target` or `custom_environment_ids` must be set.
        """
        return pulumi.get(self, "custom_environment_ids")

    @custom_environment_ids.setter
    def custom_environment_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "custom_environment_ids", value)

    @_builtins.property
    @pulumi.getter(name="gitBranch")
    def git_branch(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The git branch of the Environment Variable.
        """
        return pulumi.get(self, "git_branch")

    @git_branch.setter
    def git_branch(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "git_branch", value)

    @_builtins.property
    @pulumi.getter
    def sensitive(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether the Environment Variable is sensitive or not. (May be affected by a [team-wide environment variable policy](https://vercel.com/docs/projects/environment-variables/sensitive-environment-variables#environment-variables-policy))
        """
        return pulumi.get(self, "sensitive")

    @sensitive.setter
    def sensitive(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "sensitive", value)

    @_builtins.property
    @pulumi.getter
    def targets(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        The environments that the Environment Variable should be present on. Valid targets are either `production`, `preview`, or `development`. At least one of `target` or `custom_environment_ids` must be set.
        """
        return pulumi.get(self, "targets")

    @targets.setter
    def targets(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "targets", value)

    @_builtins.property
    @pulumi.getter(name="teamId")
    def team_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the Vercel team.Required when configuring a team resource if a default team has not been set in the provider.
        """
        return pulumi.get(self, "team_id")

    @team_id.setter
    def team_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "team_id", value)

    @_builtins.property
    @pulumi.getter
    def value(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (Optional, exactly one of `value` or `value_wo` is required) The value of the Environment Variable.
        """
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "value", value)

    @_builtins.property
    @pulumi.getter(name="valueWo")
    def value_wo(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        **NOTE:** This field is write-only and its value will not be updated in state as part of read operations.
        (Optional, Write-Only, exactly one of `value` or `value_wo` is required) The value of the Environment Variable, from an `ephemeral` resource.
        """
        return pulumi.get(self, "value_wo")

    @value_wo.setter
    def value_wo(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "value_wo", value)


@pulumi.input_type
class _ProjectEnvironmentVariableState:
    def __init__(__self__, *,
                 comment: Optional[pulumi.Input[_builtins.str]] = None,
                 custom_environment_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 git_branch: Optional[pulumi.Input[_builtins.str]] = None,
                 key: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 sensitive: Optional[pulumi.Input[_builtins.bool]] = None,
                 targets: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 team_id: Optional[pulumi.Input[_builtins.str]] = None,
                 value: Optional[pulumi.Input[_builtins.str]] = None,
                 value_wo: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering ProjectEnvironmentVariable resources.
        :param pulumi.Input[_builtins.str] comment: A comment explaining what the environment variable is for.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] custom_environment_ids: The IDs of Custom Environments that the Environment Variable should be present on. At least one of `target` or `custom_environment_ids` must be set.
        :param pulumi.Input[_builtins.str] git_branch: The git branch of the Environment Variable.
        :param pulumi.Input[_builtins.str] key: The name of the Environment Variable.
        :param pulumi.Input[_builtins.str] project_id: The ID of the Vercel project.
        :param pulumi.Input[_builtins.bool] sensitive: Whether the Environment Variable is sensitive or not. (May be affected by a [team-wide environment variable policy](https://vercel.com/docs/projects/environment-variables/sensitive-environment-variables#environment-variables-policy))
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] targets: The environments that the Environment Variable should be present on. Valid targets are either `production`, `preview`, or `development`. At least one of `target` or `custom_environment_ids` must be set.
        :param pulumi.Input[_builtins.str] team_id: The ID of the Vercel team.Required when configuring a team resource if a default team has not been set in the provider.
        :param pulumi.Input[_builtins.str] value: (Optional, exactly one of `value` or `value_wo` is required) The value of the Environment Variable.
        :param pulumi.Input[_builtins.str] value_wo: **NOTE:** This field is write-only and its value will not be updated in state as part of read operations.
               (Optional, Write-Only, exactly one of `value` or `value_wo` is required) The value of the Environment Variable, from an `ephemeral` resource.
        """
        if comment is not None:
            pulumi.set(__self__, "comment", comment)
        if custom_environment_ids is not None:
            pulumi.set(__self__, "custom_environment_ids", custom_environment_ids)
        if git_branch is not None:
            pulumi.set(__self__, "git_branch", git_branch)
        if key is not None:
            pulumi.set(__self__, "key", key)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if sensitive is not None:
            pulumi.set(__self__, "sensitive", sensitive)
        if targets is not None:
            pulumi.set(__self__, "targets", targets)
        if team_id is not None:
            pulumi.set(__self__, "team_id", team_id)
        if value is not None:
            pulumi.set(__self__, "value", value)
        if value_wo is not None:
            pulumi.set(__self__, "value_wo", value_wo)

    @_builtins.property
    @pulumi.getter
    def comment(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        A comment explaining what the environment variable is for.
        """
        return pulumi.get(self, "comment")

    @comment.setter
    def comment(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "comment", value)

    @_builtins.property
    @pulumi.getter(name="customEnvironmentIds")
    def custom_environment_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        The IDs of Custom Environments that the Environment Variable should be present on. At least one of `target` or `custom_environment_ids` must be set.
        """
        return pulumi.get(self, "custom_environment_ids")

    @custom_environment_ids.setter
    def custom_environment_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "custom_environment_ids", value)

    @_builtins.property
    @pulumi.getter(name="gitBranch")
    def git_branch(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The git branch of the Environment Variable.
        """
        return pulumi.get(self, "git_branch")

    @git_branch.setter
    def git_branch(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "git_branch", value)

    @_builtins.property
    @pulumi.getter
    def key(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the Environment Variable.
        """
        return pulumi.get(self, "key")

    @key.setter
    def key(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "key", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the Vercel project.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def sensitive(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether the Environment Variable is sensitive or not. (May be affected by a [team-wide environment variable policy](https://vercel.com/docs/projects/environment-variables/sensitive-environment-variables#environment-variables-policy))
        """
        return pulumi.get(self, "sensitive")

    @sensitive.setter
    def sensitive(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "sensitive", value)

    @_builtins.property
    @pulumi.getter
    def targets(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        The environments that the Environment Variable should be present on. Valid targets are either `production`, `preview`, or `development`. At least one of `target` or `custom_environment_ids` must be set.
        """
        return pulumi.get(self, "targets")

    @targets.setter
    def targets(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "targets", value)

    @_builtins.property
    @pulumi.getter(name="teamId")
    def team_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the Vercel team.Required when configuring a team resource if a default team has not been set in the provider.
        """
        return pulumi.get(self, "team_id")

    @team_id.setter
    def team_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "team_id", value)

    @_builtins.property
    @pulumi.getter
    def value(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (Optional, exactly one of `value` or `value_wo` is required) The value of the Environment Variable.
        """
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "value", value)

    @_builtins.property
    @pulumi.getter(name="valueWo")
    def value_wo(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        **NOTE:** This field is write-only and its value will not be updated in state as part of read operations.
        (Optional, Write-Only, exactly one of `value` or `value_wo` is required) The value of the Environment Variable, from an `ephemeral` resource.
        """
        return pulumi.get(self, "value_wo")

    @value_wo.setter
    def value_wo(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "value_wo", value)


@pulumi.type_token("vercel:index/projectEnvironmentVariable:ProjectEnvironmentVariable")
class ProjectEnvironmentVariable(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 comment: Optional[pulumi.Input[_builtins.str]] = None,
                 custom_environment_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 git_branch: Optional[pulumi.Input[_builtins.str]] = None,
                 key: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 sensitive: Optional[pulumi.Input[_builtins.bool]] = None,
                 targets: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 team_id: Optional[pulumi.Input[_builtins.str]] = None,
                 value: Optional[pulumi.Input[_builtins.str]] = None,
                 value_wo: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        ## Example Usage

        ## Import

        If importing into a personal account, or with a team configured on

        the provider, simply use the project_id and environment variable id.

        - project_id can be found in the project `settings` tab in the Vercel UI.

        - environment variable id can be taken from the network tab inside developer tools, while you are on the project page,

        or can be queried from Vercel API directly (https://vercel.com/docs/rest-api/endpoints/projects#retrieve-the-environment-variables-of-a-project-by-id-or-name)

        Note also, that the value field for sensitive environment variables will be imported as `null`.

        ```sh
        $ pulumi import vercel:index/projectEnvironmentVariable:ProjectEnvironmentVariable example prj_xxxxxxxxxxxxxxxxxxxxxxxxxxxx/FdT2e1E5Of6Cihmt
        ```

        Alternatively, you can import via the team_id, project_id and

        environment variable id.

        - team_id can be found in the team `settings` tab in the Vercel UI.

        - project_id can be found in the project `settings` tab in the Vercel UI.

        - environment variable id can be taken from the network tab inside developer tools, while you are on the project page,

        or can be queried from Vercel API directly (https://vercel.com/docs/rest-api/endpoints/projects#retrieve-the-environment-variables-of-a-project-by-id-or-name)

        Note also, that the value field for sensitive environment variables will be imported as `null`.

        ```sh
        $ pulumi import vercel:index/projectEnvironmentVariable:ProjectEnvironmentVariable example team_xxxxxxxxxxxxxxxxxxxxxxxx/prj_xxxxxxxxxxxxxxxxxxxxxxxxxxxx/FdT2e1E5Of6Cihmt
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] comment: A comment explaining what the environment variable is for.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] custom_environment_ids: The IDs of Custom Environments that the Environment Variable should be present on. At least one of `target` or `custom_environment_ids` must be set.
        :param pulumi.Input[_builtins.str] git_branch: The git branch of the Environment Variable.
        :param pulumi.Input[_builtins.str] key: The name of the Environment Variable.
        :param pulumi.Input[_builtins.str] project_id: The ID of the Vercel project.
        :param pulumi.Input[_builtins.bool] sensitive: Whether the Environment Variable is sensitive or not. (May be affected by a [team-wide environment variable policy](https://vercel.com/docs/projects/environment-variables/sensitive-environment-variables#environment-variables-policy))
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] targets: The environments that the Environment Variable should be present on. Valid targets are either `production`, `preview`, or `development`. At least one of `target` or `custom_environment_ids` must be set.
        :param pulumi.Input[_builtins.str] team_id: The ID of the Vercel team.Required when configuring a team resource if a default team has not been set in the provider.
        :param pulumi.Input[_builtins.str] value: (Optional, exactly one of `value` or `value_wo` is required) The value of the Environment Variable.
        :param pulumi.Input[_builtins.str] value_wo: **NOTE:** This field is write-only and its value will not be updated in state as part of read operations.
               (Optional, Write-Only, exactly one of `value` or `value_wo` is required) The value of the Environment Variable, from an `ephemeral` resource.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ProjectEnvironmentVariableArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Example Usage

        ## Import

        If importing into a personal account, or with a team configured on

        the provider, simply use the project_id and environment variable id.

        - project_id can be found in the project `settings` tab in the Vercel UI.

        - environment variable id can be taken from the network tab inside developer tools, while you are on the project page,

        or can be queried from Vercel API directly (https://vercel.com/docs/rest-api/endpoints/projects#retrieve-the-environment-variables-of-a-project-by-id-or-name)

        Note also, that the value field for sensitive environment variables will be imported as `null`.

        ```sh
        $ pulumi import vercel:index/projectEnvironmentVariable:ProjectEnvironmentVariable example prj_xxxxxxxxxxxxxxxxxxxxxxxxxxxx/FdT2e1E5Of6Cihmt
        ```

        Alternatively, you can import via the team_id, project_id and

        environment variable id.

        - team_id can be found in the team `settings` tab in the Vercel UI.

        - project_id can be found in the project `settings` tab in the Vercel UI.

        - environment variable id can be taken from the network tab inside developer tools, while you are on the project page,

        or can be queried from Vercel API directly (https://vercel.com/docs/rest-api/endpoints/projects#retrieve-the-environment-variables-of-a-project-by-id-or-name)

        Note also, that the value field for sensitive environment variables will be imported as `null`.

        ```sh
        $ pulumi import vercel:index/projectEnvironmentVariable:ProjectEnvironmentVariable example team_xxxxxxxxxxxxxxxxxxxxxxxx/prj_xxxxxxxxxxxxxxxxxxxxxxxxxxxx/FdT2e1E5Of6Cihmt
        ```

        :param str resource_name: The name of the resource.
        :param ProjectEnvironmentVariableArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ProjectEnvironmentVariableArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 comment: Optional[pulumi.Input[_builtins.str]] = None,
                 custom_environment_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 git_branch: Optional[pulumi.Input[_builtins.str]] = None,
                 key: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 sensitive: Optional[pulumi.Input[_builtins.bool]] = None,
                 targets: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 team_id: Optional[pulumi.Input[_builtins.str]] = None,
                 value: Optional[pulumi.Input[_builtins.str]] = None,
                 value_wo: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ProjectEnvironmentVariableArgs.__new__(ProjectEnvironmentVariableArgs)

            __props__.__dict__["comment"] = comment
            __props__.__dict__["custom_environment_ids"] = custom_environment_ids
            __props__.__dict__["git_branch"] = git_branch
            if key is None and not opts.urn:
                raise TypeError("Missing required property 'key'")
            __props__.__dict__["key"] = key
            if project_id is None and not opts.urn:
                raise TypeError("Missing required property 'project_id'")
            __props__.__dict__["project_id"] = project_id
            __props__.__dict__["sensitive"] = sensitive
            __props__.__dict__["targets"] = targets
            __props__.__dict__["team_id"] = team_id
            __props__.__dict__["value"] = None if value is None else pulumi.Output.secret(value)
            __props__.__dict__["value_wo"] = None if value_wo is None else pulumi.Output.secret(value_wo)
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["value", "valueWo"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(ProjectEnvironmentVariable, __self__).__init__(
            'vercel:index/projectEnvironmentVariable:ProjectEnvironmentVariable',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            comment: Optional[pulumi.Input[_builtins.str]] = None,
            custom_environment_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            git_branch: Optional[pulumi.Input[_builtins.str]] = None,
            key: Optional[pulumi.Input[_builtins.str]] = None,
            project_id: Optional[pulumi.Input[_builtins.str]] = None,
            sensitive: Optional[pulumi.Input[_builtins.bool]] = None,
            targets: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            team_id: Optional[pulumi.Input[_builtins.str]] = None,
            value: Optional[pulumi.Input[_builtins.str]] = None,
            value_wo: Optional[pulumi.Input[_builtins.str]] = None) -> 'ProjectEnvironmentVariable':
        """
        Get an existing ProjectEnvironmentVariable resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] comment: A comment explaining what the environment variable is for.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] custom_environment_ids: The IDs of Custom Environments that the Environment Variable should be present on. At least one of `target` or `custom_environment_ids` must be set.
        :param pulumi.Input[_builtins.str] git_branch: The git branch of the Environment Variable.
        :param pulumi.Input[_builtins.str] key: The name of the Environment Variable.
        :param pulumi.Input[_builtins.str] project_id: The ID of the Vercel project.
        :param pulumi.Input[_builtins.bool] sensitive: Whether the Environment Variable is sensitive or not. (May be affected by a [team-wide environment variable policy](https://vercel.com/docs/projects/environment-variables/sensitive-environment-variables#environment-variables-policy))
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] targets: The environments that the Environment Variable should be present on. Valid targets are either `production`, `preview`, or `development`. At least one of `target` or `custom_environment_ids` must be set.
        :param pulumi.Input[_builtins.str] team_id: The ID of the Vercel team.Required when configuring a team resource if a default team has not been set in the provider.
        :param pulumi.Input[_builtins.str] value: (Optional, exactly one of `value` or `value_wo` is required) The value of the Environment Variable.
        :param pulumi.Input[_builtins.str] value_wo: **NOTE:** This field is write-only and its value will not be updated in state as part of read operations.
               (Optional, Write-Only, exactly one of `value` or `value_wo` is required) The value of the Environment Variable, from an `ephemeral` resource.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ProjectEnvironmentVariableState.__new__(_ProjectEnvironmentVariableState)

        __props__.__dict__["comment"] = comment
        __props__.__dict__["custom_environment_ids"] = custom_environment_ids
        __props__.__dict__["git_branch"] = git_branch
        __props__.__dict__["key"] = key
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["sensitive"] = sensitive
        __props__.__dict__["targets"] = targets
        __props__.__dict__["team_id"] = team_id
        __props__.__dict__["value"] = value
        __props__.__dict__["value_wo"] = value_wo
        return ProjectEnvironmentVariable(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def comment(self) -> pulumi.Output[_builtins.str]:
        """
        A comment explaining what the environment variable is for.
        """
        return pulumi.get(self, "comment")

    @_builtins.property
    @pulumi.getter(name="customEnvironmentIds")
    def custom_environment_ids(self) -> pulumi.Output[Sequence[_builtins.str]]:
        """
        The IDs of Custom Environments that the Environment Variable should be present on. At least one of `target` or `custom_environment_ids` must be set.
        """
        return pulumi.get(self, "custom_environment_ids")

    @_builtins.property
    @pulumi.getter(name="gitBranch")
    def git_branch(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The git branch of the Environment Variable.
        """
        return pulumi.get(self, "git_branch")

    @_builtins.property
    @pulumi.getter
    def key(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the Environment Variable.
        """
        return pulumi.get(self, "key")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[_builtins.str]:
        """
        The ID of the Vercel project.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def sensitive(self) -> pulumi.Output[_builtins.bool]:
        """
        Whether the Environment Variable is sensitive or not. (May be affected by a [team-wide environment variable policy](https://vercel.com/docs/projects/environment-variables/sensitive-environment-variables#environment-variables-policy))
        """
        return pulumi.get(self, "sensitive")

    @_builtins.property
    @pulumi.getter
    def targets(self) -> pulumi.Output[Sequence[_builtins.str]]:
        """
        The environments that the Environment Variable should be present on. Valid targets are either `production`, `preview`, or `development`. At least one of `target` or `custom_environment_ids` must be set.
        """
        return pulumi.get(self, "targets")

    @_builtins.property
    @pulumi.getter(name="teamId")
    def team_id(self) -> pulumi.Output[_builtins.str]:
        """
        The ID of the Vercel team.Required when configuring a team resource if a default team has not been set in the provider.
        """
        return pulumi.get(self, "team_id")

    @_builtins.property
    @pulumi.getter
    def value(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        (Optional, exactly one of `value` or `value_wo` is required) The value of the Environment Variable.
        """
        return pulumi.get(self, "value")

    @_builtins.property
    @pulumi.getter(name="valueWo")
    def value_wo(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        **NOTE:** This field is write-only and its value will not be updated in state as part of read operations.
        (Optional, Write-Only, exactly one of `value` or `value_wo` is required) The value of the Environment Variable, from an `ephemeral` resource.
        """
        return pulumi.get(self, "value_wo")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetNetworkResult',
    'AwaitableGetNetworkResult',
    'get_network',
    'get_network_output',
]

@pulumi.output_type
class GetNetworkResult:
    """
    A collection of values returned by getNetwork.
    """
    def __init__(__self__, aws_account_id=None, aws_availability_zone_ids=None, aws_region=None, cidr=None, egress_ip_addresses=None, id=None, name=None, region=None, status=None, team_id=None, vpc_id=None):
        if aws_account_id and not isinstance(aws_account_id, str):
            raise TypeError("Expected argument 'aws_account_id' to be a str")
        pulumi.set(__self__, "aws_account_id", aws_account_id)
        if aws_availability_zone_ids and not isinstance(aws_availability_zone_ids, list):
            raise TypeError("Expected argument 'aws_availability_zone_ids' to be a list")
        pulumi.set(__self__, "aws_availability_zone_ids", aws_availability_zone_ids)
        if aws_region and not isinstance(aws_region, str):
            raise TypeError("Expected argument 'aws_region' to be a str")
        pulumi.set(__self__, "aws_region", aws_region)
        if cidr and not isinstance(cidr, str):
            raise TypeError("Expected argument 'cidr' to be a str")
        pulumi.set(__self__, "cidr", cidr)
        if egress_ip_addresses and not isinstance(egress_ip_addresses, list):
            raise TypeError("Expected argument 'egress_ip_addresses' to be a list")
        pulumi.set(__self__, "egress_ip_addresses", egress_ip_addresses)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if region and not isinstance(region, str):
            raise TypeError("Expected argument 'region' to be a str")
        pulumi.set(__self__, "region", region)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if team_id and not isinstance(team_id, str):
            raise TypeError("Expected argument 'team_id' to be a str")
        pulumi.set(__self__, "team_id", team_id)
        if vpc_id and not isinstance(vpc_id, str):
            raise TypeError("Expected argument 'vpc_id' to be a str")
        pulumi.set(__self__, "vpc_id", vpc_id)

    @_builtins.property
    @pulumi.getter(name="awsAccountId")
    def aws_account_id(self) -> _builtins.str:
        """
        The ID of the AWS Account in which the network exists.
        """
        return pulumi.get(self, "aws_account_id")

    @_builtins.property
    @pulumi.getter(name="awsAvailabilityZoneIds")
    def aws_availability_zone_ids(self) -> Sequence[_builtins.str]:
        """
        The IDs of the AWS Availability Zones in which the network exists, if specified during creation.
        """
        return pulumi.get(self, "aws_availability_zone_ids")

    @_builtins.property
    @pulumi.getter(name="awsRegion")
    def aws_region(self) -> _builtins.str:
        """
        The AWS Region in which the network exists.
        """
        return pulumi.get(self, "aws_region")

    @_builtins.property
    @pulumi.getter
    def cidr(self) -> _builtins.str:
        """
        The CIDR range of the Network.
        """
        return pulumi.get(self, "cidr")

    @_builtins.property
    @pulumi.getter(name="egressIpAddresses")
    def egress_ip_addresses(self) -> Sequence[_builtins.str]:
        """
        The egress IP addresses of the Network.
        """
        return pulumi.get(self, "egress_ip_addresses")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The unique identifier of the Network.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        The name of the network.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def region(self) -> _builtins.str:
        """
        The Vercel region in which the Network exists.
        """
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter
    def status(self) -> _builtins.str:
        """
        The status of the Network.
        """
        return pulumi.get(self, "status")

    @_builtins.property
    @pulumi.getter(name="teamId")
    def team_id(self) -> Optional[_builtins.str]:
        """
        The unique identifier of the Team that owns the Network. Required when configuring a team resource if a default team has not been set in the provider.
        """
        return pulumi.get(self, "team_id")

    @_builtins.property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> _builtins.str:
        """
        The ID of the AWS VPC which hosts the network.
        """
        return pulumi.get(self, "vpc_id")


class AwaitableGetNetworkResult(GetNetworkResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetNetworkResult(
            aws_account_id=self.aws_account_id,
            aws_availability_zone_ids=self.aws_availability_zone_ids,
            aws_region=self.aws_region,
            cidr=self.cidr,
            egress_ip_addresses=self.egress_ip_addresses,
            id=self.id,
            name=self.name,
            region=self.region,
            status=self.status,
            team_id=self.team_id,
            vpc_id=self.vpc_id)


def get_network(id: Optional[_builtins.str] = None,
                team_id: Optional[_builtins.str] = None,
                opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetNetworkResult:
    """
    Provides information about a Vercel Network.


    :param _builtins.str id: The unique identifier of the Network.
    :param _builtins.str team_id: The unique identifier of the Team that owns the Network. Required when configuring a team resource if a default team has not been set in the provider.
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['teamId'] = team_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('vercel:index/getNetwork:getNetwork', __args__, opts=opts, typ=GetNetworkResult).value

    return AwaitableGetNetworkResult(
        aws_account_id=pulumi.get(__ret__, 'aws_account_id'),
        aws_availability_zone_ids=pulumi.get(__ret__, 'aws_availability_zone_ids'),
        aws_region=pulumi.get(__ret__, 'aws_region'),
        cidr=pulumi.get(__ret__, 'cidr'),
        egress_ip_addresses=pulumi.get(__ret__, 'egress_ip_addresses'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        region=pulumi.get(__ret__, 'region'),
        status=pulumi.get(__ret__, 'status'),
        team_id=pulumi.get(__ret__, 'team_id'),
        vpc_id=pulumi.get(__ret__, 'vpc_id'))
def get_network_output(id: Optional[pulumi.Input[_builtins.str]] = None,
                       team_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                       opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetNetworkResult]:
    """
    Provides information about a Vercel Network.


    :param _builtins.str id: The unique identifier of the Network.
    :param _builtins.str team_id: The unique identifier of the Team that owns the Network. Required when configuring a team resource if a default team has not been set in the provider.
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['teamId'] = team_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('vercel:index/getNetwork:getNetwork', __args__, opts=opts, typ=GetNetworkResult)
    return __ret__.apply(lambda __response__: GetNetworkResult(
        aws_account_id=pulumi.get(__response__, 'aws_account_id'),
        aws_availability_zone_ids=pulumi.get(__response__, 'aws_availability_zone_ids'),
        aws_region=pulumi.get(__response__, 'aws_region'),
        cidr=pulumi.get(__response__, 'cidr'),
        egress_ip_addresses=pulumi.get(__response__, 'egress_ip_addresses'),
        id=pulumi.get(__response__, 'id'),
        name=pulumi.get(__response__, 'name'),
        region=pulumi.get(__response__, 'region'),
        status=pulumi.get(__response__, 'status'),
        team_id=pulumi.get(__response__, 'team_id'),
        vpc_id=pulumi.get(__response__, 'vpc_id')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetTeamMemberResult',
    'AwaitableGetTeamMemberResult',
    'get_team_member',
    'get_team_member_output',
]

@pulumi.output_type
class GetTeamMemberResult:
    """
    A collection of values returned by getTeamMember.
    """
    def __init__(__self__, access_groups=None, email=None, id=None, projects=None, role=None, team_id=None, user_id=None):
        if access_groups and not isinstance(access_groups, list):
            raise TypeError("Expected argument 'access_groups' to be a list")
        pulumi.set(__self__, "access_groups", access_groups)
        if email and not isinstance(email, str):
            raise TypeError("Expected argument 'email' to be a str")
        pulumi.set(__self__, "email", email)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if projects and not isinstance(projects, list):
            raise TypeError("Expected argument 'projects' to be a list")
        pulumi.set(__self__, "projects", projects)
        if role and not isinstance(role, str):
            raise TypeError("Expected argument 'role' to be a str")
        pulumi.set(__self__, "role", role)
        if team_id and not isinstance(team_id, str):
            raise TypeError("Expected argument 'team_id' to be a str")
        pulumi.set(__self__, "team_id", team_id)
        if user_id and not isinstance(user_id, str):
            raise TypeError("Expected argument 'user_id' to be a str")
        pulumi.set(__self__, "user_id", user_id)

    @_builtins.property
    @pulumi.getter(name="accessGroups")
    def access_groups(self) -> Sequence[_builtins.str]:
        """
        If access groups are enabled on the team, and the user is a CONTRIBUTOR, `projects`, `access_groups` or both must be specified. A set of access groups IDs that the user should be granted access to.
        """
        return pulumi.get(self, "access_groups")

    @_builtins.property
    @pulumi.getter
    def email(self) -> _builtins.str:
        """
        The email address of the existing Vercel Team Member.
        """
        return pulumi.get(self, "email")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The ID of this resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def projects(self) -> Sequence['outputs.GetTeamMemberProjectResult']:
        """
        If access groups are enabled on the team, and the user is a CONTRIBUTOR, `projects`, `access_groups` or both must be specified. A set of projects that the user should be granted access to, along with their role in each project.
        """
        return pulumi.get(self, "projects")

    @_builtins.property
    @pulumi.getter
    def role(self) -> _builtins.str:
        """
        The role that the user should have in the project. One of 'MEMBER', 'OWNER', 'VIEWER', 'DEVELOPER', 'BILLING' or 'CONTRIBUTOR'. Depending on your Team's plan, some of these roles may be unavailable.
        """
        return pulumi.get(self, "role")

    @_builtins.property
    @pulumi.getter(name="teamId")
    def team_id(self) -> _builtins.str:
        """
        The ID of the existing Vercel Team.
        """
        return pulumi.get(self, "team_id")

    @_builtins.property
    @pulumi.getter(name="userId")
    def user_id(self) -> _builtins.str:
        """
        The ID of the existing Vercel Team Member.
        """
        return pulumi.get(self, "user_id")


class AwaitableGetTeamMemberResult(GetTeamMemberResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetTeamMemberResult(
            access_groups=self.access_groups,
            email=self.email,
            id=self.id,
            projects=self.projects,
            role=self.role,
            team_id=self.team_id,
            user_id=self.user_id)


def get_team_member(team_id: Optional[_builtins.str] = None,
                    user_id: Optional[_builtins.str] = None,
                    opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetTeamMemberResult:
    """
    Provider a datasource for managing a team member.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_vercel as vercel

    example = vercel.get_team_member(user_id="uuuuuuuuuuuuuuuuuuuuuuuuuu",
        team_id="team_xxxxxxxxxxxxxxxxxxxxxxxx")
    ```


    :param _builtins.str team_id: The ID of the existing Vercel Team.
    :param _builtins.str user_id: The ID of the existing Vercel Team Member.
    """
    __args__ = dict()
    __args__['teamId'] = team_id
    __args__['userId'] = user_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('vercel:index/getTeamMember:getTeamMember', __args__, opts=opts, typ=GetTeamMemberResult).value

    return AwaitableGetTeamMemberResult(
        access_groups=pulumi.get(__ret__, 'access_groups'),
        email=pulumi.get(__ret__, 'email'),
        id=pulumi.get(__ret__, 'id'),
        projects=pulumi.get(__ret__, 'projects'),
        role=pulumi.get(__ret__, 'role'),
        team_id=pulumi.get(__ret__, 'team_id'),
        user_id=pulumi.get(__ret__, 'user_id'))
def get_team_member_output(team_id: Optional[pulumi.Input[_builtins.str]] = None,
                           user_id: Optional[pulumi.Input[_builtins.str]] = None,
                           opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetTeamMemberResult]:
    """
    Provider a datasource for managing a team member.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_vercel as vercel

    example = vercel.get_team_member(user_id="uuuuuuuuuuuuuuuuuuuuuuuuuu",
        team_id="team_xxxxxxxxxxxxxxxxxxxxxxxx")
    ```


    :param _builtins.str team_id: The ID of the existing Vercel Team.
    :param _builtins.str user_id: The ID of the existing Vercel Team Member.
    """
    __args__ = dict()
    __args__['teamId'] = team_id
    __args__['userId'] = user_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('vercel:index/getTeamMember:getTeamMember', __args__, opts=opts, typ=GetTeamMemberResult)
    return __ret__.apply(lambda __response__: GetTeamMemberResult(
        access_groups=pulumi.get(__response__, 'access_groups'),
        email=pulumi.get(__response__, 'email'),
        id=pulumi.get(__response__, 'id'),
        projects=pulumi.get(__response__, 'projects'),
        role=pulumi.get(__response__, 'role'),
        team_id=pulumi.get(__response__, 'team_id'),
        user_id=pulumi.get(__response__, 'user_id')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetLogDrainResult',
    'AwaitableGetLogDrainResult',
    'get_log_drain',
    'get_log_drain_output',
]

@pulumi.output_type
class GetLogDrainResult:
    """
    A collection of values returned by getLogDrain.
    """
    def __init__(__self__, delivery_format=None, endpoint=None, environments=None, headers=None, id=None, name=None, project_ids=None, sampling_rate=None, sources=None, team_id=None):
        if delivery_format and not isinstance(delivery_format, str):
            raise TypeError("Expected argument 'delivery_format' to be a str")
        pulumi.set(__self__, "delivery_format", delivery_format)
        if endpoint and not isinstance(endpoint, str):
            raise TypeError("Expected argument 'endpoint' to be a str")
        pulumi.set(__self__, "endpoint", endpoint)
        if environments and not isinstance(environments, list):
            raise TypeError("Expected argument 'environments' to be a list")
        pulumi.set(__self__, "environments", environments)
        if headers and not isinstance(headers, dict):
            raise TypeError("Expected argument 'headers' to be a dict")
        pulumi.set(__self__, "headers", headers)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if project_ids and not isinstance(project_ids, list):
            raise TypeError("Expected argument 'project_ids' to be a list")
        pulumi.set(__self__, "project_ids", project_ids)
        if sampling_rate and not isinstance(sampling_rate, float):
            raise TypeError("Expected argument 'sampling_rate' to be a float")
        pulumi.set(__self__, "sampling_rate", sampling_rate)
        if sources and not isinstance(sources, list):
            raise TypeError("Expected argument 'sources' to be a list")
        pulumi.set(__self__, "sources", sources)
        if team_id and not isinstance(team_id, str):
            raise TypeError("Expected argument 'team_id' to be a str")
        pulumi.set(__self__, "team_id", team_id)

    @_builtins.property
    @pulumi.getter(name="deliveryFormat")
    def delivery_format(self) -> _builtins.str:
        """
        The format log data should be delivered in. Can be `json` or `ndjson`.
        """
        return pulumi.get(self, "delivery_format")

    @_builtins.property
    @pulumi.getter
    def endpoint(self) -> _builtins.str:
        """
        Logs will be sent as POST requests to this URL. The endpoint will be verified, and must return a `200` status code and an `x-vercel-verify` header taken from the endpoint_verification data source. The value the `x-vercel-verify` header should be can be read from the `vercel_endpoint_verification_code` data source.
        """
        return pulumi.get(self, "endpoint")

    @_builtins.property
    @pulumi.getter
    def environments(self) -> Sequence[_builtins.str]:
        """
        Logs from the selected environments will be forwarded to your webhook. At least one must be present.
        """
        return pulumi.get(self, "environments")

    @_builtins.property
    @pulumi.getter
    def headers(self) -> Mapping[str, _builtins.str]:
        """
        Custom headers to include in requests to the log drain endpoint.
        """
        return pulumi.get(self, "headers")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The ID of the Log Drain.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        The human-readable name of the Log Drain.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="projectIds")
    def project_ids(self) -> Sequence[_builtins.str]:
        """
        A list of project IDs that the log drain should be associated with. Logs from these projects will be sent log events to the specified endpoint. If omitted, logs will be sent for all projects.
        """
        return pulumi.get(self, "project_ids")

    @_builtins.property
    @pulumi.getter(name="samplingRate")
    def sampling_rate(self) -> _builtins.float:
        """
        A ratio of logs matching the sampling rate will be sent to your log drain. Should be a value between 0 and 1. If unspecified, all logs are sent.
        """
        return pulumi.get(self, "sampling_rate")

    @_builtins.property
    @pulumi.getter
    def sources(self) -> Sequence[_builtins.str]:
        """
        A set of sources that the log drain should send logs for. Valid values are `static`, `edge`, `external`, `build`, `lambda`, `firewall`, and `redirect`.
        """
        return pulumi.get(self, "sources")

    @_builtins.property
    @pulumi.getter(name="teamId")
    def team_id(self) -> _builtins.str:
        """
        The ID of the team the Log Drain should exist under. Required when configuring a team resource if a default team has not been set in the provider.
        """
        return pulumi.get(self, "team_id")


class AwaitableGetLogDrainResult(GetLogDrainResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetLogDrainResult(
            delivery_format=self.delivery_format,
            endpoint=self.endpoint,
            environments=self.environments,
            headers=self.headers,
            id=self.id,
            name=self.name,
            project_ids=self.project_ids,
            sampling_rate=self.sampling_rate,
            sources=self.sources,
            team_id=self.team_id)


def get_log_drain(endpoint: Optional[_builtins.str] = None,
                  id: Optional[_builtins.str] = None,
                  team_id: Optional[_builtins.str] = None,
                  opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetLogDrainResult:
    """
    Provides information about an existing Log Drain.

    Log Drains collect all of your logs using a service specializing in storing app logs.

    Teams on Pro and Enterprise plans can subscribe to log drains that are generic and configurable from the Vercel dashboard without creating an integration. This allows you to use a HTTP service to receive logs through Vercel's log drains.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_vercel as vercel

    example = vercel.get_log_drain(id="lg_xxxxxxx_xxxxxx_xxxxx")
    ```


    :param _builtins.str endpoint: Logs will be sent as POST requests to this URL. The endpoint will be verified, and must return a `200` status code and an `x-vercel-verify` header taken from the endpoint_verification data source. The value the `x-vercel-verify` header should be can be read from the `vercel_endpoint_verification_code` data source.
    :param _builtins.str id: The ID of the Log Drain.
    :param _builtins.str team_id: The ID of the team the Log Drain should exist under. Required when configuring a team resource if a default team has not been set in the provider.
    """
    __args__ = dict()
    __args__['endpoint'] = endpoint
    __args__['id'] = id
    __args__['teamId'] = team_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('vercel:index/getLogDrain:getLogDrain', __args__, opts=opts, typ=GetLogDrainResult).value

    return AwaitableGetLogDrainResult(
        delivery_format=pulumi.get(__ret__, 'delivery_format'),
        endpoint=pulumi.get(__ret__, 'endpoint'),
        environments=pulumi.get(__ret__, 'environments'),
        headers=pulumi.get(__ret__, 'headers'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        project_ids=pulumi.get(__ret__, 'project_ids'),
        sampling_rate=pulumi.get(__ret__, 'sampling_rate'),
        sources=pulumi.get(__ret__, 'sources'),
        team_id=pulumi.get(__ret__, 'team_id'))
def get_log_drain_output(endpoint: Optional[pulumi.Input[_builtins.str]] = None,
                         id: Optional[pulumi.Input[_builtins.str]] = None,
                         team_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                         opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetLogDrainResult]:
    """
    Provides information about an existing Log Drain.

    Log Drains collect all of your logs using a service specializing in storing app logs.

    Teams on Pro and Enterprise plans can subscribe to log drains that are generic and configurable from the Vercel dashboard without creating an integration. This allows you to use a HTTP service to receive logs through Vercel's log drains.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_vercel as vercel

    example = vercel.get_log_drain(id="lg_xxxxxxx_xxxxxx_xxxxx")
    ```


    :param _builtins.str endpoint: Logs will be sent as POST requests to this URL. The endpoint will be verified, and must return a `200` status code and an `x-vercel-verify` header taken from the endpoint_verification data source. The value the `x-vercel-verify` header should be can be read from the `vercel_endpoint_verification_code` data source.
    :param _builtins.str id: The ID of the Log Drain.
    :param _builtins.str team_id: The ID of the team the Log Drain should exist under. Required when configuring a team resource if a default team has not been set in the provider.
    """
    __args__ = dict()
    __args__['endpoint'] = endpoint
    __args__['id'] = id
    __args__['teamId'] = team_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('vercel:index/getLogDrain:getLogDrain', __args__, opts=opts, typ=GetLogDrainResult)
    return __ret__.apply(lambda __response__: GetLogDrainResult(
        delivery_format=pulumi.get(__response__, 'delivery_format'),
        endpoint=pulumi.get(__response__, 'endpoint'),
        environments=pulumi.get(__response__, 'environments'),
        headers=pulumi.get(__response__, 'headers'),
        id=pulumi.get(__response__, 'id'),
        name=pulumi.get(__response__, 'name'),
        project_ids=pulumi.get(__response__, 'project_ids'),
        sampling_rate=pulumi.get(__response__, 'sampling_rate'),
        sources=pulumi.get(__response__, 'sources'),
        team_id=pulumi.get(__response__, 'team_id')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['FirewallBypassArgs', 'FirewallBypass']

@pulumi.input_type
class FirewallBypassArgs:
    def __init__(__self__, *,
                 domain: pulumi.Input[_builtins.str],
                 project_id: pulumi.Input[_builtins.str],
                 source_ip: pulumi.Input[_builtins.str],
                 note: Optional[pulumi.Input[_builtins.str]] = None,
                 team_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a FirewallBypass resource.
        :param pulumi.Input[_builtins.str] domain: The domain to configure the bypass rule for.
        :param pulumi.Input[_builtins.str] project_id: The ID of the Project to assign the bypass rule to
        :param pulumi.Input[_builtins.str] source_ip: The source IP address to configure the bypass rule for.
        :param pulumi.Input[_builtins.str] note: A note to describe the bypass rule. Maximum length is 500 characters.
        :param pulumi.Input[_builtins.str] team_id: The ID of the team the Project exists under. Required when configuring a team resource if a default team has not been set in the provider.
        """
        pulumi.set(__self__, "domain", domain)
        pulumi.set(__self__, "project_id", project_id)
        pulumi.set(__self__, "source_ip", source_ip)
        if note is not None:
            pulumi.set(__self__, "note", note)
        if team_id is not None:
            pulumi.set(__self__, "team_id", team_id)

    @_builtins.property
    @pulumi.getter
    def domain(self) -> pulumi.Input[_builtins.str]:
        """
        The domain to configure the bypass rule for.
        """
        return pulumi.get(self, "domain")

    @domain.setter
    def domain(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "domain", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Input[_builtins.str]:
        """
        The ID of the Project to assign the bypass rule to
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter(name="sourceIp")
    def source_ip(self) -> pulumi.Input[_builtins.str]:
        """
        The source IP address to configure the bypass rule for.
        """
        return pulumi.get(self, "source_ip")

    @source_ip.setter
    def source_ip(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "source_ip", value)

    @_builtins.property
    @pulumi.getter
    def note(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        A note to describe the bypass rule. Maximum length is 500 characters.
        """
        return pulumi.get(self, "note")

    @note.setter
    def note(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "note", value)

    @_builtins.property
    @pulumi.getter(name="teamId")
    def team_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the team the Project exists under. Required when configuring a team resource if a default team has not been set in the provider.
        """
        return pulumi.get(self, "team_id")

    @team_id.setter
    def team_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "team_id", value)


@pulumi.input_type
class _FirewallBypassState:
    def __init__(__self__, *,
                 domain: Optional[pulumi.Input[_builtins.str]] = None,
                 note: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 source_ip: Optional[pulumi.Input[_builtins.str]] = None,
                 team_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering FirewallBypass resources.
        :param pulumi.Input[_builtins.str] domain: The domain to configure the bypass rule for.
        :param pulumi.Input[_builtins.str] note: A note to describe the bypass rule. Maximum length is 500 characters.
        :param pulumi.Input[_builtins.str] project_id: The ID of the Project to assign the bypass rule to
        :param pulumi.Input[_builtins.str] source_ip: The source IP address to configure the bypass rule for.
        :param pulumi.Input[_builtins.str] team_id: The ID of the team the Project exists under. Required when configuring a team resource if a default team has not been set in the provider.
        """
        if domain is not None:
            pulumi.set(__self__, "domain", domain)
        if note is not None:
            pulumi.set(__self__, "note", note)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if source_ip is not None:
            pulumi.set(__self__, "source_ip", source_ip)
        if team_id is not None:
            pulumi.set(__self__, "team_id", team_id)

    @_builtins.property
    @pulumi.getter
    def domain(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The domain to configure the bypass rule for.
        """
        return pulumi.get(self, "domain")

    @domain.setter
    def domain(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "domain", value)

    @_builtins.property
    @pulumi.getter
    def note(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        A note to describe the bypass rule. Maximum length is 500 characters.
        """
        return pulumi.get(self, "note")

    @note.setter
    def note(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "note", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the Project to assign the bypass rule to
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter(name="sourceIp")
    def source_ip(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The source IP address to configure the bypass rule for.
        """
        return pulumi.get(self, "source_ip")

    @source_ip.setter
    def source_ip(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "source_ip", value)

    @_builtins.property
    @pulumi.getter(name="teamId")
    def team_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the team the Project exists under. Required when configuring a team resource if a default team has not been set in the provider.
        """
        return pulumi.get(self, "team_id")

    @team_id.setter
    def team_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "team_id", value)


@pulumi.type_token("vercel:index/firewallBypass:FirewallBypass")
class FirewallBypass(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 domain: Optional[pulumi.Input[_builtins.str]] = None,
                 note: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 source_ip: Optional[pulumi.Input[_builtins.str]] = None,
                 team_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Provides a Firewall Bypass Rule

        Firewall Bypass Rules configure sets of domains and ip address to prevent bypass Vercel's system mitigations for.  The hosts used in a bypass rule must be a production domain assigned to the associated project.  Requests that bypass system mitigations will incur usage.

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_vercel as vercel

        example = vercel.Project("example", name="firewall-bypass-example")
        bypass_targeted = vercel.FirewallBypass("bypass_targeted",
            project_id=example.id,
            source_ip="5.6.7.8",
            domain="my-production-domain.com",
            note="Bypass rule for specific IP")
        bypass_cidr = vercel.FirewallBypass("bypass_cidr",
            project_id=example.id,
            source_ip="52.33.44.0/24",
            domain="my-production-domain.com",
            note="Bypass rule for CIDR range")
        bypass_all = vercel.FirewallBypass("bypass_all",
            project_id=example.id,
            source_ip="52.33.44.0/24",
            domain="*")
        ```

        ## Import

        ```sh
        $ pulumi import vercel:index/firewallBypass:FirewallBypass example team_xxxxxxxxxxxxxxxxxxxxxxxx/prj_xxxxxxxxxxxxxxxxxxxxxxxxxxxx#mybypasshost.com#3.4.5.0/24
        ```

        ```sh
        $ pulumi import vercel:index/firewallBypass:FirewallBypass example team_xxxxxxxxxxxxxxxxxxxxxxxx/prj_xxxxxxxxxxxxxxxxxxxxxxxxxxxx#3.4.5.0/24
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] domain: The domain to configure the bypass rule for.
        :param pulumi.Input[_builtins.str] note: A note to describe the bypass rule. Maximum length is 500 characters.
        :param pulumi.Input[_builtins.str] project_id: The ID of the Project to assign the bypass rule to
        :param pulumi.Input[_builtins.str] source_ip: The source IP address to configure the bypass rule for.
        :param pulumi.Input[_builtins.str] team_id: The ID of the team the Project exists under. Required when configuring a team resource if a default team has not been set in the provider.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: FirewallBypassArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Firewall Bypass Rule

        Firewall Bypass Rules configure sets of domains and ip address to prevent bypass Vercel's system mitigations for.  The hosts used in a bypass rule must be a production domain assigned to the associated project.  Requests that bypass system mitigations will incur usage.

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_vercel as vercel

        example = vercel.Project("example", name="firewall-bypass-example")
        bypass_targeted = vercel.FirewallBypass("bypass_targeted",
            project_id=example.id,
            source_ip="5.6.7.8",
            domain="my-production-domain.com",
            note="Bypass rule for specific IP")
        bypass_cidr = vercel.FirewallBypass("bypass_cidr",
            project_id=example.id,
            source_ip="52.33.44.0/24",
            domain="my-production-domain.com",
            note="Bypass rule for CIDR range")
        bypass_all = vercel.FirewallBypass("bypass_all",
            project_id=example.id,
            source_ip="52.33.44.0/24",
            domain="*")
        ```

        ## Import

        ```sh
        $ pulumi import vercel:index/firewallBypass:FirewallBypass example team_xxxxxxxxxxxxxxxxxxxxxxxx/prj_xxxxxxxxxxxxxxxxxxxxxxxxxxxx#mybypasshost.com#3.4.5.0/24
        ```

        ```sh
        $ pulumi import vercel:index/firewallBypass:FirewallBypass example team_xxxxxxxxxxxxxxxxxxxxxxxx/prj_xxxxxxxxxxxxxxxxxxxxxxxxxxxx#3.4.5.0/24
        ```

        :param str resource_name: The name of the resource.
        :param FirewallBypassArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(FirewallBypassArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 domain: Optional[pulumi.Input[_builtins.str]] = None,
                 note: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 source_ip: Optional[pulumi.Input[_builtins.str]] = None,
                 team_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = FirewallBypassArgs.__new__(FirewallBypassArgs)

            if domain is None and not opts.urn:
                raise TypeError("Missing required property 'domain'")
            __props__.__dict__["domain"] = domain
            __props__.__dict__["note"] = note
            if project_id is None and not opts.urn:
                raise TypeError("Missing required property 'project_id'")
            __props__.__dict__["project_id"] = project_id
            if source_ip is None and not opts.urn:
                raise TypeError("Missing required property 'source_ip'")
            __props__.__dict__["source_ip"] = source_ip
            __props__.__dict__["team_id"] = team_id
        super(FirewallBypass, __self__).__init__(
            'vercel:index/firewallBypass:FirewallBypass',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            domain: Optional[pulumi.Input[_builtins.str]] = None,
            note: Optional[pulumi.Input[_builtins.str]] = None,
            project_id: Optional[pulumi.Input[_builtins.str]] = None,
            source_ip: Optional[pulumi.Input[_builtins.str]] = None,
            team_id: Optional[pulumi.Input[_builtins.str]] = None) -> 'FirewallBypass':
        """
        Get an existing FirewallBypass resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] domain: The domain to configure the bypass rule for.
        :param pulumi.Input[_builtins.str] note: A note to describe the bypass rule. Maximum length is 500 characters.
        :param pulumi.Input[_builtins.str] project_id: The ID of the Project to assign the bypass rule to
        :param pulumi.Input[_builtins.str] source_ip: The source IP address to configure the bypass rule for.
        :param pulumi.Input[_builtins.str] team_id: The ID of the team the Project exists under. Required when configuring a team resource if a default team has not been set in the provider.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _FirewallBypassState.__new__(_FirewallBypassState)

        __props__.__dict__["domain"] = domain
        __props__.__dict__["note"] = note
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["source_ip"] = source_ip
        __props__.__dict__["team_id"] = team_id
        return FirewallBypass(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def domain(self) -> pulumi.Output[_builtins.str]:
        """
        The domain to configure the bypass rule for.
        """
        return pulumi.get(self, "domain")

    @_builtins.property
    @pulumi.getter
    def note(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        A note to describe the bypass rule. Maximum length is 500 characters.
        """
        return pulumi.get(self, "note")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[_builtins.str]:
        """
        The ID of the Project to assign the bypass rule to
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter(name="sourceIp")
    def source_ip(self) -> pulumi.Output[_builtins.str]:
        """
        The source IP address to configure the bypass rule for.
        """
        return pulumi.get(self, "source_ip")

    @_builtins.property
    @pulumi.getter(name="teamId")
    def team_id(self) -> pulumi.Output[_builtins.str]:
        """
        The ID of the team the Project exists under. Required when configuring a team resource if a default team has not been set in the provider.
        """
        return pulumi.get(self, "team_id")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['FirewallConfigArgs', 'FirewallConfig']

@pulumi.input_type
class FirewallConfigArgs:
    def __init__(__self__, *,
                 project_id: pulumi.Input[_builtins.str],
                 enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 ip_rules: Optional[pulumi.Input['FirewallConfigIpRulesArgs']] = None,
                 managed_rulesets: Optional[pulumi.Input['FirewallConfigManagedRulesetsArgs']] = None,
                 rules: Optional[pulumi.Input['FirewallConfigRulesArgs']] = None,
                 team_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a FirewallConfig resource.
        :param pulumi.Input[_builtins.str] project_id: The ID of the project this configuration belongs to.
        :param pulumi.Input[_builtins.bool] enabled: Whether firewall is enabled or not.
        :param pulumi.Input['FirewallConfigIpRulesArgs'] ip_rules: IP rules to apply to the project.
        :param pulumi.Input['FirewallConfigManagedRulesetsArgs'] managed_rulesets: The managed rulesets that are enabled.
        :param pulumi.Input['FirewallConfigRulesArgs'] rules: Custom rules to apply to the project
        :param pulumi.Input[_builtins.str] team_id: The ID of the team this project belongs to.
        """
        pulumi.set(__self__, "project_id", project_id)
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)
        if ip_rules is not None:
            pulumi.set(__self__, "ip_rules", ip_rules)
        if managed_rulesets is not None:
            pulumi.set(__self__, "managed_rulesets", managed_rulesets)
        if rules is not None:
            pulumi.set(__self__, "rules", rules)
        if team_id is not None:
            pulumi.set(__self__, "team_id", team_id)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Input[_builtins.str]:
        """
        The ID of the project this configuration belongs to.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether firewall is enabled or not.
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "enabled", value)

    @_builtins.property
    @pulumi.getter(name="ipRules")
    def ip_rules(self) -> Optional[pulumi.Input['FirewallConfigIpRulesArgs']]:
        """
        IP rules to apply to the project.
        """
        return pulumi.get(self, "ip_rules")

    @ip_rules.setter
    def ip_rules(self, value: Optional[pulumi.Input['FirewallConfigIpRulesArgs']]):
        pulumi.set(self, "ip_rules", value)

    @_builtins.property
    @pulumi.getter(name="managedRulesets")
    def managed_rulesets(self) -> Optional[pulumi.Input['FirewallConfigManagedRulesetsArgs']]:
        """
        The managed rulesets that are enabled.
        """
        return pulumi.get(self, "managed_rulesets")

    @managed_rulesets.setter
    def managed_rulesets(self, value: Optional[pulumi.Input['FirewallConfigManagedRulesetsArgs']]):
        pulumi.set(self, "managed_rulesets", value)

    @_builtins.property
    @pulumi.getter
    def rules(self) -> Optional[pulumi.Input['FirewallConfigRulesArgs']]:
        """
        Custom rules to apply to the project
        """
        return pulumi.get(self, "rules")

    @rules.setter
    def rules(self, value: Optional[pulumi.Input['FirewallConfigRulesArgs']]):
        pulumi.set(self, "rules", value)

    @_builtins.property
    @pulumi.getter(name="teamId")
    def team_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the team this project belongs to.
        """
        return pulumi.get(self, "team_id")

    @team_id.setter
    def team_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "team_id", value)


@pulumi.input_type
class _FirewallConfigState:
    def __init__(__self__, *,
                 enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 ip_rules: Optional[pulumi.Input['FirewallConfigIpRulesArgs']] = None,
                 managed_rulesets: Optional[pulumi.Input['FirewallConfigManagedRulesetsArgs']] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 rules: Optional[pulumi.Input['FirewallConfigRulesArgs']] = None,
                 team_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering FirewallConfig resources.
        :param pulumi.Input[_builtins.bool] enabled: Whether firewall is enabled or not.
        :param pulumi.Input['FirewallConfigIpRulesArgs'] ip_rules: IP rules to apply to the project.
        :param pulumi.Input['FirewallConfigManagedRulesetsArgs'] managed_rulesets: The managed rulesets that are enabled.
        :param pulumi.Input[_builtins.str] project_id: The ID of the project this configuration belongs to.
        :param pulumi.Input['FirewallConfigRulesArgs'] rules: Custom rules to apply to the project
        :param pulumi.Input[_builtins.str] team_id: The ID of the team this project belongs to.
        """
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)
        if ip_rules is not None:
            pulumi.set(__self__, "ip_rules", ip_rules)
        if managed_rulesets is not None:
            pulumi.set(__self__, "managed_rulesets", managed_rulesets)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if rules is not None:
            pulumi.set(__self__, "rules", rules)
        if team_id is not None:
            pulumi.set(__self__, "team_id", team_id)

    @_builtins.property
    @pulumi.getter
    def enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether firewall is enabled or not.
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "enabled", value)

    @_builtins.property
    @pulumi.getter(name="ipRules")
    def ip_rules(self) -> Optional[pulumi.Input['FirewallConfigIpRulesArgs']]:
        """
        IP rules to apply to the project.
        """
        return pulumi.get(self, "ip_rules")

    @ip_rules.setter
    def ip_rules(self, value: Optional[pulumi.Input['FirewallConfigIpRulesArgs']]):
        pulumi.set(self, "ip_rules", value)

    @_builtins.property
    @pulumi.getter(name="managedRulesets")
    def managed_rulesets(self) -> Optional[pulumi.Input['FirewallConfigManagedRulesetsArgs']]:
        """
        The managed rulesets that are enabled.
        """
        return pulumi.get(self, "managed_rulesets")

    @managed_rulesets.setter
    def managed_rulesets(self, value: Optional[pulumi.Input['FirewallConfigManagedRulesetsArgs']]):
        pulumi.set(self, "managed_rulesets", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the project this configuration belongs to.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def rules(self) -> Optional[pulumi.Input['FirewallConfigRulesArgs']]:
        """
        Custom rules to apply to the project
        """
        return pulumi.get(self, "rules")

    @rules.setter
    def rules(self, value: Optional[pulumi.Input['FirewallConfigRulesArgs']]):
        pulumi.set(self, "rules", value)

    @_builtins.property
    @pulumi.getter(name="teamId")
    def team_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the team this project belongs to.
        """
        return pulumi.get(self, "team_id")

    @team_id.setter
    def team_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "team_id", value)


@pulumi.type_token("vercel:index/firewallConfig:FirewallConfig")
class FirewallConfig(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 ip_rules: Optional[pulumi.Input[Union['FirewallConfigIpRulesArgs', 'FirewallConfigIpRulesArgsDict']]] = None,
                 managed_rulesets: Optional[pulumi.Input[Union['FirewallConfigManagedRulesetsArgs', 'FirewallConfigManagedRulesetsArgsDict']]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 rules: Optional[pulumi.Input[Union['FirewallConfigRulesArgs', 'FirewallConfigRulesArgsDict']]] = None,
                 team_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Define Custom Rules to shape the way your traffic is handled by the Vercel Edge Network.

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_vercel as vercel

        example = vercel.Project("example", name="firewall-config-example")
        example_firewall_config = vercel.FirewallConfig("example",
            project_id=example.id,
            rules={
                "rules": [
                    {
                        "name": "Bypass Known request",
                        "description": "Bypass requests using internal bearer tokens",
                        "condition_groups": [
                            {
                                "conditions": [{
                                    "type": "header",
                                    "key": "Authorization",
                                    "op": "eq",
                                    "value": "Bearer internaltoken",
                                }],
                            },
                            {
                                "conditions": [{
                                    "type": "header",
                                    "key": "Authorization",
                                    "op": "eq",
                                    "value": "Bearer internaltoken2",
                                }],
                            },
                        ],
                        "action": {
                            "action": "bypass",
                        },
                    },
                    {
                        "name": "Challenge curl",
                        "description": "Challenge user agents containing 'curl'",
                        "condition_groups": [{
                            "conditions": [{
                                "type": "user_agent",
                                "op": "sub",
                                "value": "curl",
                            }],
                        }],
                        "action": {
                            "action": "challenge",
                        },
                    },
                    {
                        "name": "Deny cookieless requests",
                        "description": "requests to /api that are missing a session cookie",
                        "condition_groups": [{
                            "conditions": [
                                {
                                    "type": "path",
                                    "op": "eq",
                                    "value": "/api",
                                },
                                {
                                    "type": "cookie",
                                    "key": "_session",
                                    "neg": True,
                                    "op": "ex",
                                },
                            ],
                        }],
                        "action": {
                            "action": "challenge",
                        },
                    },
                    {
                        "name": "Require Authorization header",
                        "description": "Block requests without Authorization header",
                        "condition_groups": [{
                            "conditions": [{
                                "type": "header",
                                "key": "Authorization",
                                "op": "nex",
                            }],
                        }],
                        "action": {
                            "action": "deny",
                        },
                    },
                    {
                        "name": "Log requests with custom header",
                        "description": "Log requests that have X-Custom-Header present",
                        "condition_groups": [{
                            "conditions": [{
                                "type": "header",
                                "key": "X-Custom-Header",
                                "op": "ex",
                            }],
                        }],
                        "action": {
                            "action": "log",
                        },
                    },
                    {
                        "name": "Rate limit API",
                        "description": "apply ratelimit to requests under /api",
                        "condition_groups": [{
                            "conditions": [{
                                "type": "path",
                                "op": "pre",
                                "value": "/api",
                            }],
                        }],
                        "action": {
                            "action": "rate_limit",
                            "rate_limit": {
                                "limit": 100,
                                "window": 300,
                                "keys": [
                                    "ip",
                                    "ja4",
                                ],
                                "algo": "fixed_window",
                                "action": "deny",
                            },
                            "action_duration": "5m",
                        },
                    },
                    {
                        "name": "Known clients",
                        "description": "Match known keys in header",
                        "condition_groups": [{
                            "conditions": [{
                                "type": "header",
                                "key": "Authorization",
                                "op": "inc",
                                "values": [
                                    "key1",
                                    "key2",
                                ],
                            }],
                        }],
                        "action": {
                            "action": "rate_limit",
                            "rate_limit": {
                                "limit": 100,
                                "window": 300,
                                "keys": [
                                    "ip",
                                    "ja4",
                                ],
                                "algo": "fixed_window",
                                "action": "deny",
                            },
                            "action_duration": "5m",
                        },
                    },
                ],
            })
        managed_example = vercel.Project("managed_example", name="firewall-managed-rule-example")
        managed = vercel.FirewallConfig("managed",
            project_id=managed_vercel_project["id"],
            managed_rulesets={
                "owasp": {
                    "xss": {
                        "action": "deny",
                    },
                    "sqli": {
                        "action": "deny",
                    },
                    "rce": {
                        "action": "deny",
                    },
                    "php": {
                        "action": "deny",
                    },
                    "java": {
                        "action": "deny",
                    },
                    "lfi": {
                        "action": "deny",
                    },
                    "rfi": {
                        "action": "deny",
                    },
                    "gen": {
                        "action": "deny",
                    },
                },
                "bot_protection": {
                    "action": "log",
                    "active": True,
                },
                "ai_bots": {
                    "action": "log",
                    "active": True,
                },
            })
        ip_example = vercel.Project("ip_example", name="firewall-ip-blocking-example")
        ip_blocking = vercel.FirewallConfig("ip-blocking",
            project_id=ip_example.id,
            ip_rules={
                "rules": [
                    {
                        "action": "deny",
                        "ip": "51.85.0.0/16",
                        "hostname": "*",
                    },
                    {
                        "action": "challenge",
                        "ip": "1.2.3.4",
                        "hostname": "example.com",
                    },
                ],
            })
        ```

        ## Import

        ```sh
        $ pulumi import vercel:index/firewallConfig:FirewallConfig example team_xxxxxxxxxxxxxxxxxxxxxxxx/prj_xxxxxxxxxxxxxxxxxxxxxxxxxxxx
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.bool] enabled: Whether firewall is enabled or not.
        :param pulumi.Input[Union['FirewallConfigIpRulesArgs', 'FirewallConfigIpRulesArgsDict']] ip_rules: IP rules to apply to the project.
        :param pulumi.Input[Union['FirewallConfigManagedRulesetsArgs', 'FirewallConfigManagedRulesetsArgsDict']] managed_rulesets: The managed rulesets that are enabled.
        :param pulumi.Input[_builtins.str] project_id: The ID of the project this configuration belongs to.
        :param pulumi.Input[Union['FirewallConfigRulesArgs', 'FirewallConfigRulesArgsDict']] rules: Custom rules to apply to the project
        :param pulumi.Input[_builtins.str] team_id: The ID of the team this project belongs to.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: FirewallConfigArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Define Custom Rules to shape the way your traffic is handled by the Vercel Edge Network.

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_vercel as vercel

        example = vercel.Project("example", name="firewall-config-example")
        example_firewall_config = vercel.FirewallConfig("example",
            project_id=example.id,
            rules={
                "rules": [
                    {
                        "name": "Bypass Known request",
                        "description": "Bypass requests using internal bearer tokens",
                        "condition_groups": [
                            {
                                "conditions": [{
                                    "type": "header",
                                    "key": "Authorization",
                                    "op": "eq",
                                    "value": "Bearer internaltoken",
                                }],
                            },
                            {
                                "conditions": [{
                                    "type": "header",
                                    "key": "Authorization",
                                    "op": "eq",
                                    "value": "Bearer internaltoken2",
                                }],
                            },
                        ],
                        "action": {
                            "action": "bypass",
                        },
                    },
                    {
                        "name": "Challenge curl",
                        "description": "Challenge user agents containing 'curl'",
                        "condition_groups": [{
                            "conditions": [{
                                "type": "user_agent",
                                "op": "sub",
                                "value": "curl",
                            }],
                        }],
                        "action": {
                            "action": "challenge",
                        },
                    },
                    {
                        "name": "Deny cookieless requests",
                        "description": "requests to /api that are missing a session cookie",
                        "condition_groups": [{
                            "conditions": [
                                {
                                    "type": "path",
                                    "op": "eq",
                                    "value": "/api",
                                },
                                {
                                    "type": "cookie",
                                    "key": "_session",
                                    "neg": True,
                                    "op": "ex",
                                },
                            ],
                        }],
                        "action": {
                            "action": "challenge",
                        },
                    },
                    {
                        "name": "Require Authorization header",
                        "description": "Block requests without Authorization header",
                        "condition_groups": [{
                            "conditions": [{
                                "type": "header",
                                "key": "Authorization",
                                "op": "nex",
                            }],
                        }],
                        "action": {
                            "action": "deny",
                        },
                    },
                    {
                        "name": "Log requests with custom header",
                        "description": "Log requests that have X-Custom-Header present",
                        "condition_groups": [{
                            "conditions": [{
                                "type": "header",
                                "key": "X-Custom-Header",
                                "op": "ex",
                            }],
                        }],
                        "action": {
                            "action": "log",
                        },
                    },
                    {
                        "name": "Rate limit API",
                        "description": "apply ratelimit to requests under /api",
                        "condition_groups": [{
                            "conditions": [{
                                "type": "path",
                                "op": "pre",
                                "value": "/api",
                            }],
                        }],
                        "action": {
                            "action": "rate_limit",
                            "rate_limit": {
                                "limit": 100,
                                "window": 300,
                                "keys": [
                                    "ip",
                                    "ja4",
                                ],
                                "algo": "fixed_window",
                                "action": "deny",
                            },
                            "action_duration": "5m",
                        },
                    },
                    {
                        "name": "Known clients",
                        "description": "Match known keys in header",
                        "condition_groups": [{
                            "conditions": [{
                                "type": "header",
                                "key": "Authorization",
                                "op": "inc",
                                "values": [
                                    "key1",
                                    "key2",
                                ],
                            }],
                        }],
                        "action": {
                            "action": "rate_limit",
                            "rate_limit": {
                                "limit": 100,
                                "window": 300,
                                "keys": [
                                    "ip",
                                    "ja4",
                                ],
                                "algo": "fixed_window",
                                "action": "deny",
                            },
                            "action_duration": "5m",
                        },
                    },
                ],
            })
        managed_example = vercel.Project("managed_example", name="firewall-managed-rule-example")
        managed = vercel.FirewallConfig("managed",
            project_id=managed_vercel_project["id"],
            managed_rulesets={
                "owasp": {
                    "xss": {
                        "action": "deny",
                    },
                    "sqli": {
                        "action": "deny",
                    },
                    "rce": {
                        "action": "deny",
                    },
                    "php": {
                        "action": "deny",
                    },
                    "java": {
                        "action": "deny",
                    },
                    "lfi": {
                        "action": "deny",
                    },
                    "rfi": {
                        "action": "deny",
                    },
                    "gen": {
                        "action": "deny",
                    },
                },
                "bot_protection": {
                    "action": "log",
                    "active": True,
                },
                "ai_bots": {
                    "action": "log",
                    "active": True,
                },
            })
        ip_example = vercel.Project("ip_example", name="firewall-ip-blocking-example")
        ip_blocking = vercel.FirewallConfig("ip-blocking",
            project_id=ip_example.id,
            ip_rules={
                "rules": [
                    {
                        "action": "deny",
                        "ip": "51.85.0.0/16",
                        "hostname": "*",
                    },
                    {
                        "action": "challenge",
                        "ip": "1.2.3.4",
                        "hostname": "example.com",
                    },
                ],
            })
        ```

        ## Import

        ```sh
        $ pulumi import vercel:index/firewallConfig:FirewallConfig example team_xxxxxxxxxxxxxxxxxxxxxxxx/prj_xxxxxxxxxxxxxxxxxxxxxxxxxxxx
        ```

        :param str resource_name: The name of the resource.
        :param FirewallConfigArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(FirewallConfigArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 ip_rules: Optional[pulumi.Input[Union['FirewallConfigIpRulesArgs', 'FirewallConfigIpRulesArgsDict']]] = None,
                 managed_rulesets: Optional[pulumi.Input[Union['FirewallConfigManagedRulesetsArgs', 'FirewallConfigManagedRulesetsArgsDict']]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 rules: Optional[pulumi.Input[Union['FirewallConfigRulesArgs', 'FirewallConfigRulesArgsDict']]] = None,
                 team_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = FirewallConfigArgs.__new__(FirewallConfigArgs)

            __props__.__dict__["enabled"] = enabled
            __props__.__dict__["ip_rules"] = ip_rules
            __props__.__dict__["managed_rulesets"] = managed_rulesets
            if project_id is None and not opts.urn:
                raise TypeError("Missing required property 'project_id'")
            __props__.__dict__["project_id"] = project_id
            __props__.__dict__["rules"] = rules
            __props__.__dict__["team_id"] = team_id
        super(FirewallConfig, __self__).__init__(
            'vercel:index/firewallConfig:FirewallConfig',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            ip_rules: Optional[pulumi.Input[Union['FirewallConfigIpRulesArgs', 'FirewallConfigIpRulesArgsDict']]] = None,
            managed_rulesets: Optional[pulumi.Input[Union['FirewallConfigManagedRulesetsArgs', 'FirewallConfigManagedRulesetsArgsDict']]] = None,
            project_id: Optional[pulumi.Input[_builtins.str]] = None,
            rules: Optional[pulumi.Input[Union['FirewallConfigRulesArgs', 'FirewallConfigRulesArgsDict']]] = None,
            team_id: Optional[pulumi.Input[_builtins.str]] = None) -> 'FirewallConfig':
        """
        Get an existing FirewallConfig resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.bool] enabled: Whether firewall is enabled or not.
        :param pulumi.Input[Union['FirewallConfigIpRulesArgs', 'FirewallConfigIpRulesArgsDict']] ip_rules: IP rules to apply to the project.
        :param pulumi.Input[Union['FirewallConfigManagedRulesetsArgs', 'FirewallConfigManagedRulesetsArgsDict']] managed_rulesets: The managed rulesets that are enabled.
        :param pulumi.Input[_builtins.str] project_id: The ID of the project this configuration belongs to.
        :param pulumi.Input[Union['FirewallConfigRulesArgs', 'FirewallConfigRulesArgsDict']] rules: Custom rules to apply to the project
        :param pulumi.Input[_builtins.str] team_id: The ID of the team this project belongs to.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _FirewallConfigState.__new__(_FirewallConfigState)

        __props__.__dict__["enabled"] = enabled
        __props__.__dict__["ip_rules"] = ip_rules
        __props__.__dict__["managed_rulesets"] = managed_rulesets
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["rules"] = rules
        __props__.__dict__["team_id"] = team_id
        return FirewallConfig(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def enabled(self) -> pulumi.Output[_builtins.bool]:
        """
        Whether firewall is enabled or not.
        """
        return pulumi.get(self, "enabled")

    @_builtins.property
    @pulumi.getter(name="ipRules")
    def ip_rules(self) -> pulumi.Output[Optional['outputs.FirewallConfigIpRules']]:
        """
        IP rules to apply to the project.
        """
        return pulumi.get(self, "ip_rules")

    @_builtins.property
    @pulumi.getter(name="managedRulesets")
    def managed_rulesets(self) -> pulumi.Output[Optional['outputs.FirewallConfigManagedRulesets']]:
        """
        The managed rulesets that are enabled.
        """
        return pulumi.get(self, "managed_rulesets")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[_builtins.str]:
        """
        The ID of the project this configuration belongs to.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def rules(self) -> pulumi.Output[Optional['outputs.FirewallConfigRules']]:
        """
        Custom rules to apply to the project
        """
        return pulumi.get(self, "rules")

    @_builtins.property
    @pulumi.getter(name="teamId")
    def team_id(self) -> pulumi.Output[_builtins.str]:
        """
        The ID of the team this project belongs to.
        """
        return pulumi.get(self, "team_id")

